/* Generated by Cython 0.19.2 on Mon Oct 28 16:09:19 2013 */

#define PY_SSIZE_T_CLEAN
#ifndef CYTHON_USE_PYLONG_INTERNALS
#ifdef PYLONG_BITS_IN_DIGIT
#define CYTHON_USE_PYLONG_INTERNALS 0
#else
#include "pyconfig.h"
#ifdef PYLONG_BITS_IN_DIGIT
#define CYTHON_USE_PYLONG_INTERNALS 1
#else
#define CYTHON_USE_PYLONG_INTERNALS 0
#endif
#endif
#endif
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02040000
    #error Cython requires Python 2.4+.
#else
#include <stddef.h> /* For offsetof */
#ifndef offsetof
#define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
#define CYTHON_COMPILING_IN_PYPY 1
#define CYTHON_COMPILING_IN_CPYTHON 0
#else
#define CYTHON_COMPILING_IN_PYPY 0
#define CYTHON_COMPILING_IN_CPYTHON 1
#endif
#if PY_VERSION_HEX < 0x02050000
  typedef int Py_ssize_t;
  #define PY_SSIZE_T_MAX INT_MAX
  #define PY_SSIZE_T_MIN INT_MIN
  #define PY_FORMAT_SIZE_T ""
  #define CYTHON_FORMAT_SSIZE_T ""
  #define PyInt_FromSsize_t(z) PyInt_FromLong(z)
  #define PyInt_AsSsize_t(o)   __Pyx_PyInt_AsInt(o)
  #define PyNumber_Index(o)    ((PyNumber_Check(o) && !PyFloat_Check(o)) ? PyNumber_Int(o) : \
                                (PyErr_Format(PyExc_TypeError, \
                                              "expected index value, got %.200s", Py_TYPE(o)->tp_name), \
                                 (PyObject*)0))
  #define __Pyx_PyIndex_Check(o) (PyNumber_Check(o) && !PyFloat_Check(o) && \
                                  !PyComplex_Check(o))
  #define PyIndex_Check __Pyx_PyIndex_Check
  #define PyErr_WarnEx(category, message, stacklevel) PyErr_Warn(category, message)
  #define __PYX_BUILD_PY_SSIZE_T "i"
#else
  #define __PYX_BUILD_PY_SSIZE_T "n"
  #define CYTHON_FORMAT_SSIZE_T "z"
  #define __Pyx_PyIndex_Check PyIndex_Check
#endif
#if PY_VERSION_HEX < 0x02060000
  #define Py_REFCNT(ob) (((PyObject*)(ob))->ob_refcnt)
  #define Py_TYPE(ob)   (((PyObject*)(ob))->ob_type)
  #define Py_SIZE(ob)   (((PyVarObject*)(ob))->ob_size)
  #define PyVarObject_HEAD_INIT(type, size) \
          PyObject_HEAD_INIT(type) size,
  #define PyType_Modified(t)
  typedef struct {
     void *buf;
     PyObject *obj;
     Py_ssize_t len;
     Py_ssize_t itemsize;
     int readonly;
     int ndim;
     char *format;
     Py_ssize_t *shape;
     Py_ssize_t *strides;
     Py_ssize_t *suboffsets;
     void *internal;
  } Py_buffer;
  #define PyBUF_SIMPLE 0
  #define PyBUF_WRITABLE 0x0001
  #define PyBUF_FORMAT 0x0004
  #define PyBUF_ND 0x0008
  #define PyBUF_STRIDES (0x0010 | PyBUF_ND)
  #define PyBUF_C_CONTIGUOUS (0x0020 | PyBUF_STRIDES)
  #define PyBUF_F_CONTIGUOUS (0x0040 | PyBUF_STRIDES)
  #define PyBUF_ANY_CONTIGUOUS (0x0080 | PyBUF_STRIDES)
  #define PyBUF_INDIRECT (0x0100 | PyBUF_STRIDES)
  #define PyBUF_RECORDS (PyBUF_STRIDES | PyBUF_FORMAT | PyBUF_WRITABLE)
  #define PyBUF_FULL (PyBUF_INDIRECT | PyBUF_FORMAT | PyBUF_WRITABLE)
  typedef int (*getbufferproc)(PyObject *, Py_buffer *, int);
  typedef void (*releasebufferproc)(PyObject *, Py_buffer *);
#endif
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos) \
          PyCode_New(a, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos) \
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
#if PY_MAJOR_VERSION < 3 && PY_MINOR_VERSION < 6
  #define PyUnicode_FromString(s) PyUnicode_Decode(s, strlen(s), "UTF-8", "strict")
#endif
#if PY_MAJOR_VERSION >= 3
  #define Py_TPFLAGS_CHECKTYPES 0
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#if (PY_VERSION_HEX < 0x02060000) || (PY_MAJOR_VERSION >= 3)
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#if PY_VERSION_HEX < 0x02060000
  #define Py_TPFLAGS_HAVE_VERSION_TAG 0
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ? \
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
#else
  #define CYTHON_PEP393_ENABLED 0
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((k=k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#endif
#if PY_VERSION_HEX < 0x02060000
  #define PyBytesObject                PyStringObject
  #define PyBytes_Type                 PyString_Type
  #define PyBytes_Check                PyString_Check
  #define PyBytes_CheckExact           PyString_CheckExact
  #define PyBytes_FromString           PyString_FromString
  #define PyBytes_FromStringAndSize    PyString_FromStringAndSize
  #define PyBytes_FromFormat           PyString_FromFormat
  #define PyBytes_DecodeEscape         PyString_DecodeEscape
  #define PyBytes_AsString             PyString_AsString
  #define PyBytes_AsStringAndSize      PyString_AsStringAndSize
  #define PyBytes_Size                 PyString_Size
  #define PyBytes_AS_STRING            PyString_AS_STRING
  #define PyBytes_GET_SIZE             PyString_GET_SIZE
  #define PyBytes_Repr                 PyString_Repr
  #define PyBytes_Concat               PyString_Concat
  #define PyBytes_ConcatAndDel         PyString_ConcatAndDel
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj) || \
                                         PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (Py_TYPE(obj) == &PyBaseString_Type)
#endif
#if PY_VERSION_HEX < 0x02060000
  #define PySet_Check(obj)             PyObject_TypeCheck(obj, &PySet_Type)
  #define PyFrozenSet_Check(obj)       PyObject_TypeCheck(obj, &PyFrozenSet_Type)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_VERSION_HEX < 0x03020000
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if (PY_MAJOR_VERSION < 3) || (PY_VERSION_HEX >= 0x03010300)
  #define __Pyx_PySequence_GetSlice(obj, a, b) PySequence_GetSlice(obj, a, b)
  #define __Pyx_PySequence_SetSlice(obj, a, b, value) PySequence_SetSlice(obj, a, b, value)
  #define __Pyx_PySequence_DelSlice(obj, a, b) PySequence_DelSlice(obj, a, b)
#else
  #define __Pyx_PySequence_GetSlice(obj, a, b) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), (PyObject*)0) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_GetSlice(obj, a, b)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object is unsliceable", (obj)->ob_type->tp_name), (PyObject*)0)))
  #define __Pyx_PySequence_SetSlice(obj, a, b, value) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), -1) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_SetSlice(obj, a, b, value)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object doesn't support slice assignment", (obj)->ob_type->tp_name), -1)))
  #define __Pyx_PySequence_DelSlice(obj, a, b) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), -1) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_DelSlice(obj, a, b)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object doesn't support slice deletion", (obj)->ob_type->tp_name), -1)))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : PyInstanceMethod_New(func))
#endif
#if PY_VERSION_HEX < 0x02050000
  #define __Pyx_GetAttrString(o,n)   PyObject_GetAttrString((o),((char *)(n)))
  #define __Pyx_SetAttrString(o,n,a) PyObject_SetAttrString((o),((char *)(n)),(a))
  #define __Pyx_DelAttrString(o,n)   PyObject_DelAttrString((o),((char *)(n)))
#else
  #define __Pyx_GetAttrString(o,n)   PyObject_GetAttrString((o),(n))
  #define __Pyx_SetAttrString(o,n,a) PyObject_SetAttrString((o),(n),(a))
  #define __Pyx_DelAttrString(o,n)   PyObject_DelAttrString((o),(n))
#endif
#if PY_VERSION_HEX < 0x02050000
  #define __Pyx_NAMESTR(n) ((char *)(n))
  #define __Pyx_DOCSTR(n)  ((char *)(n))
#else
  #define __Pyx_NAMESTR(n) (n)
  #define __Pyx_DOCSTR(n)  (n)
#endif
#ifndef CYTHON_INLINE
  #if defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  /* Initialize NaN. The sign is irrelevant, an exponent with all bits 1 and
   a nonzero mantissa means NaN. If the first bit in the mantissa is 1, it is
   a quiet NaN. */
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif


#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
#define _USE_MATH_DEFINES
#endif
#include <math.h>
#define __PYX_HAVE__zmq__backend__cython__constants
#define __PYX_HAVE_API__zmq__backend__cython__constants
#include "zmq_compat.h"
#include "zmq.h"
#include "zmq_utils.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#ifdef PYREX_WITHOUT_ASSERTIONS
#define CYTHON_WITHOUT_ASSERTIONS
#endif

#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
typedef struct {PyObject **p; char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry; /*proto*/

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
static CYTHON_INLINE char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyObject_AsUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromUString(s)  __Pyx_PyObject_FromString((char*)s)
#define __Pyx_PyBytes_FromUString(s)   __Pyx_PyBytes_FromString((char*)s)
#define __Pyx_PyStr_FromUString(s)     __Pyx_PyStr_FromString((char*)s)
#define __Pyx_PyUnicode_FromUString(s) __Pyx_PyUnicode_FromString((char*)s)
#if PY_MAJOR_VERSION < 3
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u)
{
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return u_end - u - 1;
}
#else
#define __Pyx_Py_UNICODE_strlen Py_UNICODE_strlen
#endif
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_Owned_Py_None(b) (Py_INCREF(Py_None), Py_None)
#define __Pyx_PyBool_FromLong(b) ((b) ? (Py_INCREF(Py_True), Py_True) : (Py_INCREF(Py_False), Py_False))
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x);
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE size_t __Pyx_PyInt_AsSize_t(PyObject*);
#if CYTHON_COMPILING_IN_CPYTHON
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params() {
    PyObject* sys = NULL;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    sys = PyImport_ImportModule("sys");
    if (sys == NULL) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    if (default_encoding == NULL) goto bad;
    if (strcmp(PyBytes_AsString(default_encoding), "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        const char* default_encoding_c = PyBytes_AS_STRING(default_encoding);
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (ascii_chars_u == NULL) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (ascii_chars_b == NULL || strncmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
    }
    Py_XDECREF(sys);
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return 0;
bad:
    Py_XDECREF(sys);
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params() {
    PyObject* sys = NULL;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (sys == NULL) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    if (default_encoding == NULL) goto bad;
    default_encoding_c = PyBytes_AS_STRING(default_encoding);
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c));
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(sys);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(sys);
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


#ifdef __GNUC__
  /* Test for GCC > 2.95 */
  #if __GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95))
    #define likely(x)   __builtin_expect(!!(x), 1)
    #define unlikely(x) __builtin_expect(!!(x), 0)
  #else /* __GNUC__ > 2 ... */
    #define likely(x)   (x)
    #define unlikely(x) (x)
  #endif /* __GNUC__ > 2 ... */
#else /* __GNUC__ */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */

static PyObject *__pyx_m;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "constants.pyx",
  "constants.pxi",
};

/*--- Type declarations ---*/
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname); /*proto*/
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil) \
          if (acquire_gil) { \
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure(); \
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__); \
              PyGILState_Release(__pyx_gilstate_save); \
          } else { \
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__); \
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil) \
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext() \
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif /* CYTHON_REFNANNY */
#define __Pyx_XDECREF_SET(r, v) do {                            \
        PyObject *tmp = (PyObject *) r;                         \
        r = v; __Pyx_XDECREF(tmp);                              \
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {                             \
        PyObject *tmp = (PyObject *) r;                         \
        r = v; __Pyx_DECREF(tmp);                               \
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

static PyObject* __Pyx_Globals(void); /*proto*/

static CYTHON_INLINE unsigned char __Pyx_PyInt_AsUnsignedChar(PyObject *);

static CYTHON_INLINE unsigned short __Pyx_PyInt_AsUnsignedShort(PyObject *);

static CYTHON_INLINE unsigned int __Pyx_PyInt_AsUnsignedInt(PyObject *);

static CYTHON_INLINE char __Pyx_PyInt_AsChar(PyObject *);

static CYTHON_INLINE short __Pyx_PyInt_AsShort(PyObject *);

static CYTHON_INLINE int __Pyx_PyInt_AsInt(PyObject *);

static CYTHON_INLINE signed char __Pyx_PyInt_AsSignedChar(PyObject *);

static CYTHON_INLINE signed short __Pyx_PyInt_AsSignedShort(PyObject *);

static CYTHON_INLINE signed int __Pyx_PyInt_AsSignedInt(PyObject *);

static CYTHON_INLINE int __Pyx_PyInt_AsLongDouble(PyObject *);

static CYTHON_INLINE unsigned long __Pyx_PyInt_AsUnsignedLong(PyObject *);

static CYTHON_INLINE unsigned PY_LONG_LONG __Pyx_PyInt_AsUnsignedLongLong(PyObject *);

static CYTHON_INLINE long __Pyx_PyInt_AsLong(PyObject *);

static CYTHON_INLINE PY_LONG_LONG __Pyx_PyInt_AsLongLong(PyObject *);

static CYTHON_INLINE signed long __Pyx_PyInt_AsSignedLong(PyObject *);

static CYTHON_INLINE signed PY_LONG_LONG __Pyx_PyInt_AsSignedLongLong(PyObject *);

static int __Pyx_check_binary_version(void);

typedef struct {
    int code_line;
    PyCodeObject* code_object;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename); /*proto*/

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t); /*proto*/


/* Module declarations from 'zmq.backend.cython.libzmq' */

/* Module declarations from 'zmq.backend.cython.constants' */
#define __Pyx_MODULE_NAME "zmq.backend.cython.constants"
int __pyx_module_is_main_zmq__backend__cython__constants = 0;

/* Implementation of 'zmq.backend.cython.constants' */
static char __pyx_k_1[] = "0MQ Constants.";
static char __pyx_k_2[] = "EVENT_CONNECT_DELAYED";
static char __pyx_k_3[] = "EVENT_CONNECT_RETRIED";
static char __pyx_k_4[] = "EVENT_MONITOR_STOPPED";
static char __pyx_k_5[] = "DELAY_ATTACH_ON_CONNECT";
static char __pyx_k__FD[] = "FD";
static char __pyx_k__HWM[] = "HWM";
static char __pyx_k__PUB[] = "PUB";
static char __pyx_k__REP[] = "REP";
static char __pyx_k__REQ[] = "REQ";
static char __pyx_k__SUB[] = "SUB";
static char __pyx_k__EFSM[] = "EFSM";
static char __pyx_k__IPV6[] = "IPV6";
static char __pyx_k__MORE[] = "MORE";
static char __pyx_k__NULL[] = "NULL";
static char __pyx_k__PAIR[] = "PAIR";
static char __pyx_k__PULL[] = "PULL";
static char __pyx_k__PUSH[] = "PUSH";
static char __pyx_k__RATE[] = "RATE";
static char __pyx_k__SWAP[] = "SWAP";
static char __pyx_k__TYPE[] = "TYPE";
static char __pyx_k__XPUB[] = "XPUB";
static char __pyx_k__XSUB[] = "XSUB";
static char __pyx_k__CURVE[] = "CURVE";
static char __pyx_k__ETERM[] = "ETERM";
static char __pyx_k__PLAIN[] = "PLAIN";
static char __pyx_k__QUEUE[] = "QUEUE";
static char __pyx_k__DEALER[] = "DEALER";
static char __pyx_k__EAGAIN[] = "EAGAIN";
static char __pyx_k__EFAULT[] = "EFAULT";
static char __pyx_k__EINVAL[] = "EINVAL";
static char __pyx_k__ENODEV[] = "ENODEV";
static char __pyx_k__ENOMEM[] = "ENOMEM";
static char __pyx_k__EVENTS[] = "EVENTS";
static char __pyx_k__LINGER[] = "LINGER";
static char __pyx_k__POLLIN[] = "POLLIN";
static char __pyx_k__RCVBUF[] = "RCVBUF";
static char __pyx_k__RCVHWM[] = "RCVHWM";
static char __pyx_k__ROUTER[] = "ROUTER";
static char __pyx_k__SNDBUF[] = "SNDBUF";
static char __pyx_k__SNDHWM[] = "SNDHWM";
static char __pyx_k__STREAM[] = "STREAM";
static char __pyx_k__BACKLOG[] = "BACKLOG";
static char __pyx_k__ENOBUFS[] = "ENOBUFS";
static char __pyx_k__ENOTSUP[] = "ENOTSUP";
static char __pyx_k__NOBLOCK[] = "NOBLOCK";
static char __pyx_k__POLLERR[] = "POLLERR";
static char __pyx_k__POLLOUT[] = "POLLOUT";
static char __pyx_k__RCVMORE[] = "RCVMORE";
static char __pyx_k__SNDMORE[] = "SNDMORE";
static char __pyx_k__VERSION[] = "VERSION";
static char __pyx_k____all__[] = "__all__";
static char __pyx_k__AFFINITY[] = "AFFINITY";
static char __pyx_k__CONFLATE[] = "CONFLATE";
static char __pyx_k__DONTWAIT[] = "DONTWAIT";
static char __pyx_k__EMSGSIZE[] = "EMSGSIZE";
static char __pyx_k__EMTHREAD[] = "EMTHREAD";
static char __pyx_k__ENETDOWN[] = "ENETDOWN";
static char __pyx_k__ENOTCONN[] = "ENOTCONN";
static char __pyx_k__ENOTSOCK[] = "ENOTSOCK";
static char __pyx_k__IDENTITY[] = "IDENTITY";
static char __pyx_k__IPV4ONLY[] = "IPV4ONLY";
static char __pyx_k__RCVTIMEO[] = "RCVTIMEO";
static char __pyx_k__SNDTIMEO[] = "SNDTIMEO";
static char __pyx_k__STREAMER[] = "STREAMER";
static char __pyx_k__UPSTREAM[] = "UPSTREAM";
static char __pyx_k____dict__[] = "__dict__";
static char __pyx_k____main__[] = "__main__";
static char __pyx_k____test__[] = "__test__";
static char __pyx_k__ENETRESET[] = "ENETRESET";
static char __pyx_k__ETIMEDOUT[] = "ETIMEDOUT";
static char __pyx_k__EVENT_ALL[] = "EVENT_ALL";
static char __pyx_k__FORWARDER[] = "FORWARDER";
static char __pyx_k__IMMEDIATE[] = "IMMEDIATE";
static char __pyx_k__MECHANISM[] = "MECHANISM";
static char __pyx_k__SUBSCRIBE[] = "SUBSCRIBE";
static char __pyx_k__DOWNSTREAM[] = "DOWNSTREAM";
static char __pyx_k__EADDRINUSE[] = "EADDRINUSE";
static char __pyx_k__ECONNRESET[] = "ECONNRESET";
static char __pyx_k__HAUSNUMERO[] = "HAUSNUMERO";
static char __pyx_k__IO_THREADS[] = "IO_THREADS";
static char __pyx_k__MAXMSGSIZE[] = "MAXMSGSIZE";
static char __pyx_k__MCAST_LOOP[] = "MCAST_LOOP";
static char __pyx_k__ROUTER_RAW[] = "ROUTER_RAW";
static char __pyx_k__ZAP_DOMAIN[] = "ZAP_DOMAIN";
static char __pyx_k__EINPROGRESS[] = "EINPROGRESS";
static char __pyx_k__ENETUNREACH[] = "ENETUNREACH";
static char __pyx_k__MAX_SOCKETS[] = "MAX_SOCKETS";
static char __pyx_k__REQ_RELAXED[] = "REQ_RELAXED";
static char __pyx_k__UNSUBSCRIBE[] = "UNSUBSCRIBE";
static char __pyx_k__CURVE_SERVER[] = "CURVE_SERVER";
static char __pyx_k__EAFNOSUPPORT[] = "EAFNOSUPPORT";
static char __pyx_k__ECONNABORTED[] = "ECONNABORTED";
static char __pyx_k__ECONNREFUSED[] = "ECONNREFUSED";
static char __pyx_k__EHOSTUNREACH[] = "EHOSTUNREACH";
static char __pyx_k__EVENT_CLOSED[] = "EVENT_CLOSED";
static char __pyx_k__PLAIN_SERVER[] = "PLAIN_SERVER";
static char __pyx_k__PROBE_ROUTER[] = "PROBE_ROUTER";
static char __pyx_k__RECOVERY_IVL[] = "RECOVERY_IVL";
static char __pyx_k__XPUB_VERBOSE[] = "XPUB_VERBOSE";
static char __pyx_k__EADDRNOTAVAIL[] = "EADDRNOTAVAIL";
static char __pyx_k__LAST_ENDPOINT[] = "LAST_ENDPOINT";
static char __pyx_k__RECONNECT_IVL[] = "RECONNECT_IVL";
static char __pyx_k__REQ_CORRELATE[] = "REQ_CORRELATE";
static char __pyx_k__TCP_KEEPALIVE[] = "TCP_KEEPALIVE";
static char __pyx_k__VERSION_MAJOR[] = "VERSION_MAJOR";
static char __pyx_k__VERSION_MINOR[] = "VERSION_MINOR";
static char __pyx_k__VERSION_PATCH[] = "VERSION_PATCH";
static char __pyx_k__ENOCOMPATPROTO[] = "ENOCOMPATPROTO";
static char __pyx_k__EVENT_ACCEPTED[] = "EVENT_ACCEPTED";
static char __pyx_k__MULTICAST_HOPS[] = "MULTICAST_HOPS";
static char __pyx_k__PLAIN_PASSWORD[] = "PLAIN_PASSWORD";
static char __pyx_k__PLAIN_USERNAME[] = "PLAIN_USERNAME";
static char __pyx_k__CURVE_PUBLICKEY[] = "CURVE_PUBLICKEY";
static char __pyx_k__CURVE_SECRETKEY[] = "CURVE_SECRETKEY";
static char __pyx_k__CURVE_SERVERKEY[] = "CURVE_SERVERKEY";
static char __pyx_k__EPROTONOSUPPORT[] = "EPROTONOSUPPORT";
static char __pyx_k__EVENT_CONNECTED[] = "EVENT_CONNECTED";
static char __pyx_k__EVENT_LISTENING[] = "EVENT_LISTENING";
static char __pyx_k__FAIL_UNROUTABLE[] = "FAIL_UNROUTABLE";
static char __pyx_k__IO_THREADS_DFLT[] = "IO_THREADS_DFLT";
static char __pyx_k__ROUTER_BEHAVIOR[] = "ROUTER_BEHAVIOR";
static char __pyx_k__MAX_SOCKETS_DFLT[] = "MAX_SOCKETS_DFLT";
static char __pyx_k__ROUTER_MANDATORY[] = "ROUTER_MANDATORY";
static char __pyx_k__EVENT_BIND_FAILED[] = "EVENT_BIND_FAILED";
static char __pyx_k__RECONNECT_IVL_MAX[] = "RECONNECT_IVL_MAX";
static char __pyx_k__RECOVERY_IVL_MSEC[] = "RECOVERY_IVL_MSEC";
static char __pyx_k__TCP_ACCEPT_FILTER[] = "TCP_ACCEPT_FILTER";
static char __pyx_k__TCP_KEEPALIVE_CNT[] = "TCP_KEEPALIVE_CNT";
static char __pyx_k__EVENT_CLOSE_FAILED[] = "EVENT_CLOSE_FAILED";
static char __pyx_k__EVENT_DISCONNECTED[] = "EVENT_DISCONNECTED";
static char __pyx_k__TCP_KEEPALIVE_IDLE[] = "TCP_KEEPALIVE_IDLE";
static char __pyx_k__EVENT_ACCEPT_FAILED[] = "EVENT_ACCEPT_FAILED";
static char __pyx_k__TCP_KEEPALIVE_INTVL[] = "TCP_KEEPALIVE_INTVL";
static PyObject *__pyx_n_s_2;
static PyObject *__pyx_n_s_3;
static PyObject *__pyx_n_s_4;
static PyObject *__pyx_n_s_5;
static PyObject *__pyx_n_s__AFFINITY;
static PyObject *__pyx_n_s__BACKLOG;
static PyObject *__pyx_n_s__CONFLATE;
static PyObject *__pyx_n_s__CURVE;
static PyObject *__pyx_n_s__CURVE_PUBLICKEY;
static PyObject *__pyx_n_s__CURVE_SECRETKEY;
static PyObject *__pyx_n_s__CURVE_SERVER;
static PyObject *__pyx_n_s__CURVE_SERVERKEY;
static PyObject *__pyx_n_s__DEALER;
static PyObject *__pyx_n_s__DONTWAIT;
static PyObject *__pyx_n_s__DOWNSTREAM;
static PyObject *__pyx_n_s__EADDRINUSE;
static PyObject *__pyx_n_s__EADDRNOTAVAIL;
static PyObject *__pyx_n_s__EAFNOSUPPORT;
static PyObject *__pyx_n_s__EAGAIN;
static PyObject *__pyx_n_s__ECONNABORTED;
static PyObject *__pyx_n_s__ECONNREFUSED;
static PyObject *__pyx_n_s__ECONNRESET;
static PyObject *__pyx_n_s__EFAULT;
static PyObject *__pyx_n_s__EFSM;
static PyObject *__pyx_n_s__EHOSTUNREACH;
static PyObject *__pyx_n_s__EINPROGRESS;
static PyObject *__pyx_n_s__EINVAL;
static PyObject *__pyx_n_s__EMSGSIZE;
static PyObject *__pyx_n_s__EMTHREAD;
static PyObject *__pyx_n_s__ENETDOWN;
static PyObject *__pyx_n_s__ENETRESET;
static PyObject *__pyx_n_s__ENETUNREACH;
static PyObject *__pyx_n_s__ENOBUFS;
static PyObject *__pyx_n_s__ENOCOMPATPROTO;
static PyObject *__pyx_n_s__ENODEV;
static PyObject *__pyx_n_s__ENOMEM;
static PyObject *__pyx_n_s__ENOTCONN;
static PyObject *__pyx_n_s__ENOTSOCK;
static PyObject *__pyx_n_s__ENOTSUP;
static PyObject *__pyx_n_s__EPROTONOSUPPORT;
static PyObject *__pyx_n_s__ETERM;
static PyObject *__pyx_n_s__ETIMEDOUT;
static PyObject *__pyx_n_s__EVENTS;
static PyObject *__pyx_n_s__EVENT_ACCEPTED;
static PyObject *__pyx_n_s__EVENT_ACCEPT_FAILED;
static PyObject *__pyx_n_s__EVENT_ALL;
static PyObject *__pyx_n_s__EVENT_BIND_FAILED;
static PyObject *__pyx_n_s__EVENT_CLOSED;
static PyObject *__pyx_n_s__EVENT_CLOSE_FAILED;
static PyObject *__pyx_n_s__EVENT_CONNECTED;
static PyObject *__pyx_n_s__EVENT_DISCONNECTED;
static PyObject *__pyx_n_s__EVENT_LISTENING;
static PyObject *__pyx_n_s__FAIL_UNROUTABLE;
static PyObject *__pyx_n_s__FD;
static PyObject *__pyx_n_s__FORWARDER;
static PyObject *__pyx_n_s__HAUSNUMERO;
static PyObject *__pyx_n_s__HWM;
static PyObject *__pyx_n_s__IDENTITY;
static PyObject *__pyx_n_s__IMMEDIATE;
static PyObject *__pyx_n_s__IO_THREADS;
static PyObject *__pyx_n_s__IO_THREADS_DFLT;
static PyObject *__pyx_n_s__IPV4ONLY;
static PyObject *__pyx_n_s__IPV6;
static PyObject *__pyx_n_s__LAST_ENDPOINT;
static PyObject *__pyx_n_s__LINGER;
static PyObject *__pyx_n_s__MAXMSGSIZE;
static PyObject *__pyx_n_s__MAX_SOCKETS;
static PyObject *__pyx_n_s__MAX_SOCKETS_DFLT;
static PyObject *__pyx_n_s__MCAST_LOOP;
static PyObject *__pyx_n_s__MECHANISM;
static PyObject *__pyx_n_s__MORE;
static PyObject *__pyx_n_s__MULTICAST_HOPS;
static PyObject *__pyx_n_s__NOBLOCK;
static PyObject *__pyx_n_s__NULL;
static PyObject *__pyx_n_s__PAIR;
static PyObject *__pyx_n_s__PLAIN;
static PyObject *__pyx_n_s__PLAIN_PASSWORD;
static PyObject *__pyx_n_s__PLAIN_SERVER;
static PyObject *__pyx_n_s__PLAIN_USERNAME;
static PyObject *__pyx_n_s__POLLERR;
static PyObject *__pyx_n_s__POLLIN;
static PyObject *__pyx_n_s__POLLOUT;
static PyObject *__pyx_n_s__PROBE_ROUTER;
static PyObject *__pyx_n_s__PUB;
static PyObject *__pyx_n_s__PULL;
static PyObject *__pyx_n_s__PUSH;
static PyObject *__pyx_n_s__QUEUE;
static PyObject *__pyx_n_s__RATE;
static PyObject *__pyx_n_s__RCVBUF;
static PyObject *__pyx_n_s__RCVHWM;
static PyObject *__pyx_n_s__RCVMORE;
static PyObject *__pyx_n_s__RCVTIMEO;
static PyObject *__pyx_n_s__RECONNECT_IVL;
static PyObject *__pyx_n_s__RECONNECT_IVL_MAX;
static PyObject *__pyx_n_s__RECOVERY_IVL;
static PyObject *__pyx_n_s__RECOVERY_IVL_MSEC;
static PyObject *__pyx_n_s__REP;
static PyObject *__pyx_n_s__REQ;
static PyObject *__pyx_n_s__REQ_CORRELATE;
static PyObject *__pyx_n_s__REQ_RELAXED;
static PyObject *__pyx_n_s__ROUTER;
static PyObject *__pyx_n_s__ROUTER_BEHAVIOR;
static PyObject *__pyx_n_s__ROUTER_MANDATORY;
static PyObject *__pyx_n_s__ROUTER_RAW;
static PyObject *__pyx_n_s__SNDBUF;
static PyObject *__pyx_n_s__SNDHWM;
static PyObject *__pyx_n_s__SNDMORE;
static PyObject *__pyx_n_s__SNDTIMEO;
static PyObject *__pyx_n_s__STREAM;
static PyObject *__pyx_n_s__STREAMER;
static PyObject *__pyx_n_s__SUB;
static PyObject *__pyx_n_s__SUBSCRIBE;
static PyObject *__pyx_n_s__SWAP;
static PyObject *__pyx_n_s__TCP_ACCEPT_FILTER;
static PyObject *__pyx_n_s__TCP_KEEPALIVE;
static PyObject *__pyx_n_s__TCP_KEEPALIVE_CNT;
static PyObject *__pyx_n_s__TCP_KEEPALIVE_IDLE;
static PyObject *__pyx_n_s__TCP_KEEPALIVE_INTVL;
static PyObject *__pyx_n_s__TYPE;
static PyObject *__pyx_n_s__UNSUBSCRIBE;
static PyObject *__pyx_n_s__UPSTREAM;
static PyObject *__pyx_n_s__VERSION;
static PyObject *__pyx_n_s__VERSION_MAJOR;
static PyObject *__pyx_n_s__VERSION_MINOR;
static PyObject *__pyx_n_s__VERSION_PATCH;
static PyObject *__pyx_n_s__XPUB;
static PyObject *__pyx_n_s__XPUB_VERBOSE;
static PyObject *__pyx_n_s__XSUB;
static PyObject *__pyx_n_s__ZAP_DOMAIN;
static PyObject *__pyx_n_s____all__;
static PyObject *__pyx_n_s____dict__;
static PyObject *__pyx_n_s____main__;
static PyObject *__pyx_n_s____test__;

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
static struct PyModuleDef __pyx_moduledef = {
  #if PY_VERSION_HEX < 0x03020000
    { PyObject_HEAD_INIT(NULL) NULL, 0, NULL },
  #else
    PyModuleDef_HEAD_INIT,
  #endif
    __Pyx_NAMESTR("constants"),
    __Pyx_DOCSTR(__pyx_k_1), /* m_doc */
    -1, /* m_size */
    __pyx_methods /* m_methods */,
    NULL, /* m_reload */
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_n_s_2, __pyx_k_2, sizeof(__pyx_k_2), 0, 0, 1, 1},
  {&__pyx_n_s_3, __pyx_k_3, sizeof(__pyx_k_3), 0, 0, 1, 1},
  {&__pyx_n_s_4, __pyx_k_4, sizeof(__pyx_k_4), 0, 0, 1, 1},
  {&__pyx_n_s_5, __pyx_k_5, sizeof(__pyx_k_5), 0, 0, 1, 1},
  {&__pyx_n_s__AFFINITY, __pyx_k__AFFINITY, sizeof(__pyx_k__AFFINITY), 0, 0, 1, 1},
  {&__pyx_n_s__BACKLOG, __pyx_k__BACKLOG, sizeof(__pyx_k__BACKLOG), 0, 0, 1, 1},
  {&__pyx_n_s__CONFLATE, __pyx_k__CONFLATE, sizeof(__pyx_k__CONFLATE), 0, 0, 1, 1},
  {&__pyx_n_s__CURVE, __pyx_k__CURVE, sizeof(__pyx_k__CURVE), 0, 0, 1, 1},
  {&__pyx_n_s__CURVE_PUBLICKEY, __pyx_k__CURVE_PUBLICKEY, sizeof(__pyx_k__CURVE_PUBLICKEY), 0, 0, 1, 1},
  {&__pyx_n_s__CURVE_SECRETKEY, __pyx_k__CURVE_SECRETKEY, sizeof(__pyx_k__CURVE_SECRETKEY), 0, 0, 1, 1},
  {&__pyx_n_s__CURVE_SERVER, __pyx_k__CURVE_SERVER, sizeof(__pyx_k__CURVE_SERVER), 0, 0, 1, 1},
  {&__pyx_n_s__CURVE_SERVERKEY, __pyx_k__CURVE_SERVERKEY, sizeof(__pyx_k__CURVE_SERVERKEY), 0, 0, 1, 1},
  {&__pyx_n_s__DEALER, __pyx_k__DEALER, sizeof(__pyx_k__DEALER), 0, 0, 1, 1},
  {&__pyx_n_s__DONTWAIT, __pyx_k__DONTWAIT, sizeof(__pyx_k__DONTWAIT), 0, 0, 1, 1},
  {&__pyx_n_s__DOWNSTREAM, __pyx_k__DOWNSTREAM, sizeof(__pyx_k__DOWNSTREAM), 0, 0, 1, 1},
  {&__pyx_n_s__EADDRINUSE, __pyx_k__EADDRINUSE, sizeof(__pyx_k__EADDRINUSE), 0, 0, 1, 1},
  {&__pyx_n_s__EADDRNOTAVAIL, __pyx_k__EADDRNOTAVAIL, sizeof(__pyx_k__EADDRNOTAVAIL), 0, 0, 1, 1},
  {&__pyx_n_s__EAFNOSUPPORT, __pyx_k__EAFNOSUPPORT, sizeof(__pyx_k__EAFNOSUPPORT), 0, 0, 1, 1},
  {&__pyx_n_s__EAGAIN, __pyx_k__EAGAIN, sizeof(__pyx_k__EAGAIN), 0, 0, 1, 1},
  {&__pyx_n_s__ECONNABORTED, __pyx_k__ECONNABORTED, sizeof(__pyx_k__ECONNABORTED), 0, 0, 1, 1},
  {&__pyx_n_s__ECONNREFUSED, __pyx_k__ECONNREFUSED, sizeof(__pyx_k__ECONNREFUSED), 0, 0, 1, 1},
  {&__pyx_n_s__ECONNRESET, __pyx_k__ECONNRESET, sizeof(__pyx_k__ECONNRESET), 0, 0, 1, 1},
  {&__pyx_n_s__EFAULT, __pyx_k__EFAULT, sizeof(__pyx_k__EFAULT), 0, 0, 1, 1},
  {&__pyx_n_s__EFSM, __pyx_k__EFSM, sizeof(__pyx_k__EFSM), 0, 0, 1, 1},
  {&__pyx_n_s__EHOSTUNREACH, __pyx_k__EHOSTUNREACH, sizeof(__pyx_k__EHOSTUNREACH), 0, 0, 1, 1},
  {&__pyx_n_s__EINPROGRESS, __pyx_k__EINPROGRESS, sizeof(__pyx_k__EINPROGRESS), 0, 0, 1, 1},
  {&__pyx_n_s__EINVAL, __pyx_k__EINVAL, sizeof(__pyx_k__EINVAL), 0, 0, 1, 1},
  {&__pyx_n_s__EMSGSIZE, __pyx_k__EMSGSIZE, sizeof(__pyx_k__EMSGSIZE), 0, 0, 1, 1},
  {&__pyx_n_s__EMTHREAD, __pyx_k__EMTHREAD, sizeof(__pyx_k__EMTHREAD), 0, 0, 1, 1},
  {&__pyx_n_s__ENETDOWN, __pyx_k__ENETDOWN, sizeof(__pyx_k__ENETDOWN), 0, 0, 1, 1},
  {&__pyx_n_s__ENETRESET, __pyx_k__ENETRESET, sizeof(__pyx_k__ENETRESET), 0, 0, 1, 1},
  {&__pyx_n_s__ENETUNREACH, __pyx_k__ENETUNREACH, sizeof(__pyx_k__ENETUNREACH), 0, 0, 1, 1},
  {&__pyx_n_s__ENOBUFS, __pyx_k__ENOBUFS, sizeof(__pyx_k__ENOBUFS), 0, 0, 1, 1},
  {&__pyx_n_s__ENOCOMPATPROTO, __pyx_k__ENOCOMPATPROTO, sizeof(__pyx_k__ENOCOMPATPROTO), 0, 0, 1, 1},
  {&__pyx_n_s__ENODEV, __pyx_k__ENODEV, sizeof(__pyx_k__ENODEV), 0, 0, 1, 1},
  {&__pyx_n_s__ENOMEM, __pyx_k__ENOMEM, sizeof(__pyx_k__ENOMEM), 0, 0, 1, 1},
  {&__pyx_n_s__ENOTCONN, __pyx_k__ENOTCONN, sizeof(__pyx_k__ENOTCONN), 0, 0, 1, 1},
  {&__pyx_n_s__ENOTSOCK, __pyx_k__ENOTSOCK, sizeof(__pyx_k__ENOTSOCK), 0, 0, 1, 1},
  {&__pyx_n_s__ENOTSUP, __pyx_k__ENOTSUP, sizeof(__pyx_k__ENOTSUP), 0, 0, 1, 1},
  {&__pyx_n_s__EPROTONOSUPPORT, __pyx_k__EPROTONOSUPPORT, sizeof(__pyx_k__EPROTONOSUPPORT), 0, 0, 1, 1},
  {&__pyx_n_s__ETERM, __pyx_k__ETERM, sizeof(__pyx_k__ETERM), 0, 0, 1, 1},
  {&__pyx_n_s__ETIMEDOUT, __pyx_k__ETIMEDOUT, sizeof(__pyx_k__ETIMEDOUT), 0, 0, 1, 1},
  {&__pyx_n_s__EVENTS, __pyx_k__EVENTS, sizeof(__pyx_k__EVENTS), 0, 0, 1, 1},
  {&__pyx_n_s__EVENT_ACCEPTED, __pyx_k__EVENT_ACCEPTED, sizeof(__pyx_k__EVENT_ACCEPTED), 0, 0, 1, 1},
  {&__pyx_n_s__EVENT_ACCEPT_FAILED, __pyx_k__EVENT_ACCEPT_FAILED, sizeof(__pyx_k__EVENT_ACCEPT_FAILED), 0, 0, 1, 1},
  {&__pyx_n_s__EVENT_ALL, __pyx_k__EVENT_ALL, sizeof(__pyx_k__EVENT_ALL), 0, 0, 1, 1},
  {&__pyx_n_s__EVENT_BIND_FAILED, __pyx_k__EVENT_BIND_FAILED, sizeof(__pyx_k__EVENT_BIND_FAILED), 0, 0, 1, 1},
  {&__pyx_n_s__EVENT_CLOSED, __pyx_k__EVENT_CLOSED, sizeof(__pyx_k__EVENT_CLOSED), 0, 0, 1, 1},
  {&__pyx_n_s__EVENT_CLOSE_FAILED, __pyx_k__EVENT_CLOSE_FAILED, sizeof(__pyx_k__EVENT_CLOSE_FAILED), 0, 0, 1, 1},
  {&__pyx_n_s__EVENT_CONNECTED, __pyx_k__EVENT_CONNECTED, sizeof(__pyx_k__EVENT_CONNECTED), 0, 0, 1, 1},
  {&__pyx_n_s__EVENT_DISCONNECTED, __pyx_k__EVENT_DISCONNECTED, sizeof(__pyx_k__EVENT_DISCONNECTED), 0, 0, 1, 1},
  {&__pyx_n_s__EVENT_LISTENING, __pyx_k__EVENT_LISTENING, sizeof(__pyx_k__EVENT_LISTENING), 0, 0, 1, 1},
  {&__pyx_n_s__FAIL_UNROUTABLE, __pyx_k__FAIL_UNROUTABLE, sizeof(__pyx_k__FAIL_UNROUTABLE), 0, 0, 1, 1},
  {&__pyx_n_s__FD, __pyx_k__FD, sizeof(__pyx_k__FD), 0, 0, 1, 1},
  {&__pyx_n_s__FORWARDER, __pyx_k__FORWARDER, sizeof(__pyx_k__FORWARDER), 0, 0, 1, 1},
  {&__pyx_n_s__HAUSNUMERO, __pyx_k__HAUSNUMERO, sizeof(__pyx_k__HAUSNUMERO), 0, 0, 1, 1},
  {&__pyx_n_s__HWM, __pyx_k__HWM, sizeof(__pyx_k__HWM), 0, 0, 1, 1},
  {&__pyx_n_s__IDENTITY, __pyx_k__IDENTITY, sizeof(__pyx_k__IDENTITY), 0, 0, 1, 1},
  {&__pyx_n_s__IMMEDIATE, __pyx_k__IMMEDIATE, sizeof(__pyx_k__IMMEDIATE), 0, 0, 1, 1},
  {&__pyx_n_s__IO_THREADS, __pyx_k__IO_THREADS, sizeof(__pyx_k__IO_THREADS), 0, 0, 1, 1},
  {&__pyx_n_s__IO_THREADS_DFLT, __pyx_k__IO_THREADS_DFLT, sizeof(__pyx_k__IO_THREADS_DFLT), 0, 0, 1, 1},
  {&__pyx_n_s__IPV4ONLY, __pyx_k__IPV4ONLY, sizeof(__pyx_k__IPV4ONLY), 0, 0, 1, 1},
  {&__pyx_n_s__IPV6, __pyx_k__IPV6, sizeof(__pyx_k__IPV6), 0, 0, 1, 1},
  {&__pyx_n_s__LAST_ENDPOINT, __pyx_k__LAST_ENDPOINT, sizeof(__pyx_k__LAST_ENDPOINT), 0, 0, 1, 1},
  {&__pyx_n_s__LINGER, __pyx_k__LINGER, sizeof(__pyx_k__LINGER), 0, 0, 1, 1},
  {&__pyx_n_s__MAXMSGSIZE, __pyx_k__MAXMSGSIZE, sizeof(__pyx_k__MAXMSGSIZE), 0, 0, 1, 1},
  {&__pyx_n_s__MAX_SOCKETS, __pyx_k__MAX_SOCKETS, sizeof(__pyx_k__MAX_SOCKETS), 0, 0, 1, 1},
  {&__pyx_n_s__MAX_SOCKETS_DFLT, __pyx_k__MAX_SOCKETS_DFLT, sizeof(__pyx_k__MAX_SOCKETS_DFLT), 0, 0, 1, 1},
  {&__pyx_n_s__MCAST_LOOP, __pyx_k__MCAST_LOOP, sizeof(__pyx_k__MCAST_LOOP), 0, 0, 1, 1},
  {&__pyx_n_s__MECHANISM, __pyx_k__MECHANISM, sizeof(__pyx_k__MECHANISM), 0, 0, 1, 1},
  {&__pyx_n_s__MORE, __pyx_k__MORE, sizeof(__pyx_k__MORE), 0, 0, 1, 1},
  {&__pyx_n_s__MULTICAST_HOPS, __pyx_k__MULTICAST_HOPS, sizeof(__pyx_k__MULTICAST_HOPS), 0, 0, 1, 1},
  {&__pyx_n_s__NOBLOCK, __pyx_k__NOBLOCK, sizeof(__pyx_k__NOBLOCK), 0, 0, 1, 1},
  {&__pyx_n_s__NULL, __pyx_k__NULL, sizeof(__pyx_k__NULL), 0, 0, 1, 1},
  {&__pyx_n_s__PAIR, __pyx_k__PAIR, sizeof(__pyx_k__PAIR), 0, 0, 1, 1},
  {&__pyx_n_s__PLAIN, __pyx_k__PLAIN, sizeof(__pyx_k__PLAIN), 0, 0, 1, 1},
  {&__pyx_n_s__PLAIN_PASSWORD, __pyx_k__PLAIN_PASSWORD, sizeof(__pyx_k__PLAIN_PASSWORD), 0, 0, 1, 1},
  {&__pyx_n_s__PLAIN_SERVER, __pyx_k__PLAIN_SERVER, sizeof(__pyx_k__PLAIN_SERVER), 0, 0, 1, 1},
  {&__pyx_n_s__PLAIN_USERNAME, __pyx_k__PLAIN_USERNAME, sizeof(__pyx_k__PLAIN_USERNAME), 0, 0, 1, 1},
  {&__pyx_n_s__POLLERR, __pyx_k__POLLERR, sizeof(__pyx_k__POLLERR), 0, 0, 1, 1},
  {&__pyx_n_s__POLLIN, __pyx_k__POLLIN, sizeof(__pyx_k__POLLIN), 0, 0, 1, 1},
  {&__pyx_n_s__POLLOUT, __pyx_k__POLLOUT, sizeof(__pyx_k__POLLOUT), 0, 0, 1, 1},
  {&__pyx_n_s__PROBE_ROUTER, __pyx_k__PROBE_ROUTER, sizeof(__pyx_k__PROBE_ROUTER), 0, 0, 1, 1},
  {&__pyx_n_s__PUB, __pyx_k__PUB, sizeof(__pyx_k__PUB), 0, 0, 1, 1},
  {&__pyx_n_s__PULL, __pyx_k__PULL, sizeof(__pyx_k__PULL), 0, 0, 1, 1},
  {&__pyx_n_s__PUSH, __pyx_k__PUSH, sizeof(__pyx_k__PUSH), 0, 0, 1, 1},
  {&__pyx_n_s__QUEUE, __pyx_k__QUEUE, sizeof(__pyx_k__QUEUE), 0, 0, 1, 1},
  {&__pyx_n_s__RATE, __pyx_k__RATE, sizeof(__pyx_k__RATE), 0, 0, 1, 1},
  {&__pyx_n_s__RCVBUF, __pyx_k__RCVBUF, sizeof(__pyx_k__RCVBUF), 0, 0, 1, 1},
  {&__pyx_n_s__RCVHWM, __pyx_k__RCVHWM, sizeof(__pyx_k__RCVHWM), 0, 0, 1, 1},
  {&__pyx_n_s__RCVMORE, __pyx_k__RCVMORE, sizeof(__pyx_k__RCVMORE), 0, 0, 1, 1},
  {&__pyx_n_s__RCVTIMEO, __pyx_k__RCVTIMEO, sizeof(__pyx_k__RCVTIMEO), 0, 0, 1, 1},
  {&__pyx_n_s__RECONNECT_IVL, __pyx_k__RECONNECT_IVL, sizeof(__pyx_k__RECONNECT_IVL), 0, 0, 1, 1},
  {&__pyx_n_s__RECONNECT_IVL_MAX, __pyx_k__RECONNECT_IVL_MAX, sizeof(__pyx_k__RECONNECT_IVL_MAX), 0, 0, 1, 1},
  {&__pyx_n_s__RECOVERY_IVL, __pyx_k__RECOVERY_IVL, sizeof(__pyx_k__RECOVERY_IVL), 0, 0, 1, 1},
  {&__pyx_n_s__RECOVERY_IVL_MSEC, __pyx_k__RECOVERY_IVL_MSEC, sizeof(__pyx_k__RECOVERY_IVL_MSEC), 0, 0, 1, 1},
  {&__pyx_n_s__REP, __pyx_k__REP, sizeof(__pyx_k__REP), 0, 0, 1, 1},
  {&__pyx_n_s__REQ, __pyx_k__REQ, sizeof(__pyx_k__REQ), 0, 0, 1, 1},
  {&__pyx_n_s__REQ_CORRELATE, __pyx_k__REQ_CORRELATE, sizeof(__pyx_k__REQ_CORRELATE), 0, 0, 1, 1},
  {&__pyx_n_s__REQ_RELAXED, __pyx_k__REQ_RELAXED, sizeof(__pyx_k__REQ_RELAXED), 0, 0, 1, 1},
  {&__pyx_n_s__ROUTER, __pyx_k__ROUTER, sizeof(__pyx_k__ROUTER), 0, 0, 1, 1},
  {&__pyx_n_s__ROUTER_BEHAVIOR, __pyx_k__ROUTER_BEHAVIOR, sizeof(__pyx_k__ROUTER_BEHAVIOR), 0, 0, 1, 1},
  {&__pyx_n_s__ROUTER_MANDATORY, __pyx_k__ROUTER_MANDATORY, sizeof(__pyx_k__ROUTER_MANDATORY), 0, 0, 1, 1},
  {&__pyx_n_s__ROUTER_RAW, __pyx_k__ROUTER_RAW, sizeof(__pyx_k__ROUTER_RAW), 0, 0, 1, 1},
  {&__pyx_n_s__SNDBUF, __pyx_k__SNDBUF, sizeof(__pyx_k__SNDBUF), 0, 0, 1, 1},
  {&__pyx_n_s__SNDHWM, __pyx_k__SNDHWM, sizeof(__pyx_k__SNDHWM), 0, 0, 1, 1},
  {&__pyx_n_s__SNDMORE, __pyx_k__SNDMORE, sizeof(__pyx_k__SNDMORE), 0, 0, 1, 1},
  {&__pyx_n_s__SNDTIMEO, __pyx_k__SNDTIMEO, sizeof(__pyx_k__SNDTIMEO), 0, 0, 1, 1},
  {&__pyx_n_s__STREAM, __pyx_k__STREAM, sizeof(__pyx_k__STREAM), 0, 0, 1, 1},
  {&__pyx_n_s__STREAMER, __pyx_k__STREAMER, sizeof(__pyx_k__STREAMER), 0, 0, 1, 1},
  {&__pyx_n_s__SUB, __pyx_k__SUB, sizeof(__pyx_k__SUB), 0, 0, 1, 1},
  {&__pyx_n_s__SUBSCRIBE, __pyx_k__SUBSCRIBE, sizeof(__pyx_k__SUBSCRIBE), 0, 0, 1, 1},
  {&__pyx_n_s__SWAP, __pyx_k__SWAP, sizeof(__pyx_k__SWAP), 0, 0, 1, 1},
  {&__pyx_n_s__TCP_ACCEPT_FILTER, __pyx_k__TCP_ACCEPT_FILTER, sizeof(__pyx_k__TCP_ACCEPT_FILTER), 0, 0, 1, 1},
  {&__pyx_n_s__TCP_KEEPALIVE, __pyx_k__TCP_KEEPALIVE, sizeof(__pyx_k__TCP_KEEPALIVE), 0, 0, 1, 1},
  {&__pyx_n_s__TCP_KEEPALIVE_CNT, __pyx_k__TCP_KEEPALIVE_CNT, sizeof(__pyx_k__TCP_KEEPALIVE_CNT), 0, 0, 1, 1},
  {&__pyx_n_s__TCP_KEEPALIVE_IDLE, __pyx_k__TCP_KEEPALIVE_IDLE, sizeof(__pyx_k__TCP_KEEPALIVE_IDLE), 0, 0, 1, 1},
  {&__pyx_n_s__TCP_KEEPALIVE_INTVL, __pyx_k__TCP_KEEPALIVE_INTVL, sizeof(__pyx_k__TCP_KEEPALIVE_INTVL), 0, 0, 1, 1},
  {&__pyx_n_s__TYPE, __pyx_k__TYPE, sizeof(__pyx_k__TYPE), 0, 0, 1, 1},
  {&__pyx_n_s__UNSUBSCRIBE, __pyx_k__UNSUBSCRIBE, sizeof(__pyx_k__UNSUBSCRIBE), 0, 0, 1, 1},
  {&__pyx_n_s__UPSTREAM, __pyx_k__UPSTREAM, sizeof(__pyx_k__UPSTREAM), 0, 0, 1, 1},
  {&__pyx_n_s__VERSION, __pyx_k__VERSION, sizeof(__pyx_k__VERSION), 0, 0, 1, 1},
  {&__pyx_n_s__VERSION_MAJOR, __pyx_k__VERSION_MAJOR, sizeof(__pyx_k__VERSION_MAJOR), 0, 0, 1, 1},
  {&__pyx_n_s__VERSION_MINOR, __pyx_k__VERSION_MINOR, sizeof(__pyx_k__VERSION_MINOR), 0, 0, 1, 1},
  {&__pyx_n_s__VERSION_PATCH, __pyx_k__VERSION_PATCH, sizeof(__pyx_k__VERSION_PATCH), 0, 0, 1, 1},
  {&__pyx_n_s__XPUB, __pyx_k__XPUB, sizeof(__pyx_k__XPUB), 0, 0, 1, 1},
  {&__pyx_n_s__XPUB_VERBOSE, __pyx_k__XPUB_VERBOSE, sizeof(__pyx_k__XPUB_VERBOSE), 0, 0, 1, 1},
  {&__pyx_n_s__XSUB, __pyx_k__XSUB, sizeof(__pyx_k__XSUB), 0, 0, 1, 1},
  {&__pyx_n_s__ZAP_DOMAIN, __pyx_k__ZAP_DOMAIN, sizeof(__pyx_k__ZAP_DOMAIN), 0, 0, 1, 1},
  {&__pyx_n_s____all__, __pyx_k____all__, sizeof(__pyx_k____all__), 0, 0, 1, 1},
  {&__pyx_n_s____dict__, __pyx_k____dict__, sizeof(__pyx_k____dict__), 0, 0, 1, 1},
  {&__pyx_n_s____main__, __pyx_k____main__, sizeof(__pyx_k____main__), 0, 0, 1, 1},
  {&__pyx_n_s____test__, __pyx_k____test__, sizeof(__pyx_k____test__), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static int __Pyx_InitCachedBuiltins(void) {
  return 0;
}

static int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  return 0;
  __pyx_L1_error:;
  return -1;
}

#if PY_MAJOR_VERSION < 3
PyMODINIT_FUNC initconstants(void); /*proto*/
PyMODINIT_FUNC initconstants(void)
#else
PyMODINIT_FUNC PyInit_constants(void); /*proto*/
PyMODINIT_FUNC PyInit_constants(void)
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
      PyErr_Clear();
      __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
      if (!__Pyx_RefNanny)
          Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  __Pyx_RefNannySetupContext("PyMODINIT_FUNC PyInit_constants(void)", 0);
  if ( __Pyx_check_binary_version() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #ifdef __Pyx_CyFunction_USED
  if (__Pyx_CyFunction_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4(__Pyx_NAMESTR("constants"), __pyx_methods, __Pyx_DOCSTR(__pyx_k_1), 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  Py_INCREF(__pyx_d);
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (!PyDict_GetItemString(modules, "zmq.backend.cython.constants")) {
      if (unlikely(PyDict_SetItemString(modules, "zmq.backend.cython.constants", __pyx_m) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
  }
  #endif
  __pyx_b = PyImport_AddModule(__Pyx_NAMESTR(__Pyx_BUILTIN_MODULE_NAME)); if (unlikely(!__pyx_b)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if CYTHON_COMPILING_IN_PYPY
  Py_INCREF(__pyx_b);
  #endif
  if (__Pyx_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  /*--- Initialize various global constants etc. ---*/
  if (unlikely(__Pyx_InitGlobals() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  if (__pyx_module_is_main_zmq__backend__cython__constants) {
    if (__Pyx_SetAttrString(__pyx_m, "__name__", __pyx_n_s____main__) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  }
  /*--- Builtin init code ---*/
  if (unlikely(__Pyx_InitCachedBuiltins() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Constants init code ---*/
  if (unlikely(__Pyx_InitCachedConstants() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Global init code ---*/
  /*--- Variable export code ---*/
  /*--- Function export code ---*/
  /*--- Type init code ---*/
  /*--- Type import code ---*/
  /*--- Variable import code ---*/
  /*--- Function import code ---*/
  /*--- Execution code ---*/

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":5
 * #-----------------------------------------------------------------------------
 * 
 * VERSION = ZMQ_VERSION             # <<<<<<<<<<<<<<
 * VERSION_MAJOR = ZMQ_VERSION_MAJOR
 * VERSION_MINOR = ZMQ_VERSION_MINOR
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_VERSION); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 5; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__VERSION, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 5; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":6
 * 
 * VERSION = ZMQ_VERSION
 * VERSION_MAJOR = ZMQ_VERSION_MAJOR             # <<<<<<<<<<<<<<
 * VERSION_MINOR = ZMQ_VERSION_MINOR
 * VERSION_PATCH = ZMQ_VERSION_PATCH
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_VERSION_MAJOR); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 6; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__VERSION_MAJOR, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 6; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":7
 * VERSION = ZMQ_VERSION
 * VERSION_MAJOR = ZMQ_VERSION_MAJOR
 * VERSION_MINOR = ZMQ_VERSION_MINOR             # <<<<<<<<<<<<<<
 * VERSION_PATCH = ZMQ_VERSION_PATCH
 * NOBLOCK = ZMQ_NOBLOCK
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_VERSION_MINOR); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 7; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__VERSION_MINOR, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 7; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":8
 * VERSION_MAJOR = ZMQ_VERSION_MAJOR
 * VERSION_MINOR = ZMQ_VERSION_MINOR
 * VERSION_PATCH = ZMQ_VERSION_PATCH             # <<<<<<<<<<<<<<
 * NOBLOCK = ZMQ_NOBLOCK
 * DONTWAIT = ZMQ_DONTWAIT
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_VERSION_PATCH); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 8; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__VERSION_PATCH, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 8; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":9
 * VERSION_MINOR = ZMQ_VERSION_MINOR
 * VERSION_PATCH = ZMQ_VERSION_PATCH
 * NOBLOCK = ZMQ_NOBLOCK             # <<<<<<<<<<<<<<
 * DONTWAIT = ZMQ_DONTWAIT
 * POLLIN = ZMQ_POLLIN
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_NOBLOCK); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 9; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__NOBLOCK, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 9; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":10
 * VERSION_PATCH = ZMQ_VERSION_PATCH
 * NOBLOCK = ZMQ_NOBLOCK
 * DONTWAIT = ZMQ_DONTWAIT             # <<<<<<<<<<<<<<
 * POLLIN = ZMQ_POLLIN
 * POLLOUT = ZMQ_POLLOUT
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_DONTWAIT); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 10; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__DONTWAIT, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 10; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":11
 * NOBLOCK = ZMQ_NOBLOCK
 * DONTWAIT = ZMQ_DONTWAIT
 * POLLIN = ZMQ_POLLIN             # <<<<<<<<<<<<<<
 * POLLOUT = ZMQ_POLLOUT
 * POLLERR = ZMQ_POLLERR
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_POLLIN); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 11; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__POLLIN, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 11; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":12
 * DONTWAIT = ZMQ_DONTWAIT
 * POLLIN = ZMQ_POLLIN
 * POLLOUT = ZMQ_POLLOUT             # <<<<<<<<<<<<<<
 * POLLERR = ZMQ_POLLERR
 * SNDMORE = ZMQ_SNDMORE
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_POLLOUT); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 12; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__POLLOUT, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 12; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":13
 * POLLIN = ZMQ_POLLIN
 * POLLOUT = ZMQ_POLLOUT
 * POLLERR = ZMQ_POLLERR             # <<<<<<<<<<<<<<
 * SNDMORE = ZMQ_SNDMORE
 * STREAMER = ZMQ_STREAMER
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_POLLERR); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 13; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__POLLERR, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 13; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":14
 * POLLOUT = ZMQ_POLLOUT
 * POLLERR = ZMQ_POLLERR
 * SNDMORE = ZMQ_SNDMORE             # <<<<<<<<<<<<<<
 * STREAMER = ZMQ_STREAMER
 * FORWARDER = ZMQ_FORWARDER
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_SNDMORE); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__SNDMORE, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":15
 * POLLERR = ZMQ_POLLERR
 * SNDMORE = ZMQ_SNDMORE
 * STREAMER = ZMQ_STREAMER             # <<<<<<<<<<<<<<
 * FORWARDER = ZMQ_FORWARDER
 * QUEUE = ZMQ_QUEUE
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_STREAMER); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 15; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__STREAMER, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 15; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":16
 * SNDMORE = ZMQ_SNDMORE
 * STREAMER = ZMQ_STREAMER
 * FORWARDER = ZMQ_FORWARDER             # <<<<<<<<<<<<<<
 * QUEUE = ZMQ_QUEUE
 * IO_THREADS_DFLT = ZMQ_IO_THREADS_DFLT
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_FORWARDER); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 16; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__FORWARDER, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 16; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":17
 * STREAMER = ZMQ_STREAMER
 * FORWARDER = ZMQ_FORWARDER
 * QUEUE = ZMQ_QUEUE             # <<<<<<<<<<<<<<
 * IO_THREADS_DFLT = ZMQ_IO_THREADS_DFLT
 * MAX_SOCKETS_DFLT = ZMQ_MAX_SOCKETS_DFLT
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_QUEUE); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 17; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__QUEUE, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 17; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":18
 * FORWARDER = ZMQ_FORWARDER
 * QUEUE = ZMQ_QUEUE
 * IO_THREADS_DFLT = ZMQ_IO_THREADS_DFLT             # <<<<<<<<<<<<<<
 * MAX_SOCKETS_DFLT = ZMQ_MAX_SOCKETS_DFLT
 * PAIR = ZMQ_PAIR
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_IO_THREADS_DFLT); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 18; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__IO_THREADS_DFLT, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 18; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":19
 * QUEUE = ZMQ_QUEUE
 * IO_THREADS_DFLT = ZMQ_IO_THREADS_DFLT
 * MAX_SOCKETS_DFLT = ZMQ_MAX_SOCKETS_DFLT             # <<<<<<<<<<<<<<
 * PAIR = ZMQ_PAIR
 * PUB = ZMQ_PUB
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_MAX_SOCKETS_DFLT); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 19; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__MAX_SOCKETS_DFLT, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 19; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":20
 * IO_THREADS_DFLT = ZMQ_IO_THREADS_DFLT
 * MAX_SOCKETS_DFLT = ZMQ_MAX_SOCKETS_DFLT
 * PAIR = ZMQ_PAIR             # <<<<<<<<<<<<<<
 * PUB = ZMQ_PUB
 * SUB = ZMQ_SUB
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_PAIR); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 20; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__PAIR, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 20; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":21
 * MAX_SOCKETS_DFLT = ZMQ_MAX_SOCKETS_DFLT
 * PAIR = ZMQ_PAIR
 * PUB = ZMQ_PUB             # <<<<<<<<<<<<<<
 * SUB = ZMQ_SUB
 * REQ = ZMQ_REQ
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_PUB); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 21; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__PUB, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 21; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":22
 * PAIR = ZMQ_PAIR
 * PUB = ZMQ_PUB
 * SUB = ZMQ_SUB             # <<<<<<<<<<<<<<
 * REQ = ZMQ_REQ
 * REP = ZMQ_REP
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_SUB); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 22; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__SUB, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 22; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":23
 * PUB = ZMQ_PUB
 * SUB = ZMQ_SUB
 * REQ = ZMQ_REQ             # <<<<<<<<<<<<<<
 * REP = ZMQ_REP
 * DEALER = ZMQ_DEALER
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_REQ); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 23; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__REQ, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 23; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":24
 * SUB = ZMQ_SUB
 * REQ = ZMQ_REQ
 * REP = ZMQ_REP             # <<<<<<<<<<<<<<
 * DEALER = ZMQ_DEALER
 * ROUTER = ZMQ_ROUTER
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_REP); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 24; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__REP, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 24; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":25
 * REQ = ZMQ_REQ
 * REP = ZMQ_REP
 * DEALER = ZMQ_DEALER             # <<<<<<<<<<<<<<
 * ROUTER = ZMQ_ROUTER
 * PULL = ZMQ_PULL
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_DEALER); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 25; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__DEALER, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 25; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":26
 * REP = ZMQ_REP
 * DEALER = ZMQ_DEALER
 * ROUTER = ZMQ_ROUTER             # <<<<<<<<<<<<<<
 * PULL = ZMQ_PULL
 * PUSH = ZMQ_PUSH
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_ROUTER); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__ROUTER, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":27
 * DEALER = ZMQ_DEALER
 * ROUTER = ZMQ_ROUTER
 * PULL = ZMQ_PULL             # <<<<<<<<<<<<<<
 * PUSH = ZMQ_PUSH
 * XPUB = ZMQ_XPUB
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_PULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 27; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__PULL, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 27; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":28
 * ROUTER = ZMQ_ROUTER
 * PULL = ZMQ_PULL
 * PUSH = ZMQ_PUSH             # <<<<<<<<<<<<<<
 * XPUB = ZMQ_XPUB
 * XSUB = ZMQ_XSUB
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_PUSH); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 28; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__PUSH, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 28; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":29
 * PULL = ZMQ_PULL
 * PUSH = ZMQ_PUSH
 * XPUB = ZMQ_XPUB             # <<<<<<<<<<<<<<
 * XSUB = ZMQ_XSUB
 * UPSTREAM = ZMQ_UPSTREAM
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_XPUB); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 29; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__XPUB, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 29; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":30
 * PUSH = ZMQ_PUSH
 * XPUB = ZMQ_XPUB
 * XSUB = ZMQ_XSUB             # <<<<<<<<<<<<<<
 * UPSTREAM = ZMQ_UPSTREAM
 * DOWNSTREAM = ZMQ_DOWNSTREAM
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_XSUB); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 30; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__XSUB, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 30; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":31
 * XPUB = ZMQ_XPUB
 * XSUB = ZMQ_XSUB
 * UPSTREAM = ZMQ_UPSTREAM             # <<<<<<<<<<<<<<
 * DOWNSTREAM = ZMQ_DOWNSTREAM
 * STREAM = ZMQ_STREAM
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_UPSTREAM); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 31; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__UPSTREAM, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 31; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":32
 * XSUB = ZMQ_XSUB
 * UPSTREAM = ZMQ_UPSTREAM
 * DOWNSTREAM = ZMQ_DOWNSTREAM             # <<<<<<<<<<<<<<
 * STREAM = ZMQ_STREAM
 * EVENT_CONNECTED = ZMQ_EVENT_CONNECTED
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_DOWNSTREAM); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 32; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__DOWNSTREAM, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 32; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":33
 * UPSTREAM = ZMQ_UPSTREAM
 * DOWNSTREAM = ZMQ_DOWNSTREAM
 * STREAM = ZMQ_STREAM             # <<<<<<<<<<<<<<
 * EVENT_CONNECTED = ZMQ_EVENT_CONNECTED
 * EVENT_CONNECT_DELAYED = ZMQ_EVENT_CONNECT_DELAYED
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_STREAM); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 33; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__STREAM, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 33; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":34
 * DOWNSTREAM = ZMQ_DOWNSTREAM
 * STREAM = ZMQ_STREAM
 * EVENT_CONNECTED = ZMQ_EVENT_CONNECTED             # <<<<<<<<<<<<<<
 * EVENT_CONNECT_DELAYED = ZMQ_EVENT_CONNECT_DELAYED
 * EVENT_CONNECT_RETRIED = ZMQ_EVENT_CONNECT_RETRIED
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_EVENT_CONNECTED); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 34; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__EVENT_CONNECTED, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 34; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":35
 * STREAM = ZMQ_STREAM
 * EVENT_CONNECTED = ZMQ_EVENT_CONNECTED
 * EVENT_CONNECT_DELAYED = ZMQ_EVENT_CONNECT_DELAYED             # <<<<<<<<<<<<<<
 * EVENT_CONNECT_RETRIED = ZMQ_EVENT_CONNECT_RETRIED
 * EVENT_LISTENING = ZMQ_EVENT_LISTENING
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_EVENT_CONNECT_DELAYED); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 35; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_2, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 35; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":36
 * EVENT_CONNECTED = ZMQ_EVENT_CONNECTED
 * EVENT_CONNECT_DELAYED = ZMQ_EVENT_CONNECT_DELAYED
 * EVENT_CONNECT_RETRIED = ZMQ_EVENT_CONNECT_RETRIED             # <<<<<<<<<<<<<<
 * EVENT_LISTENING = ZMQ_EVENT_LISTENING
 * EVENT_BIND_FAILED = ZMQ_EVENT_BIND_FAILED
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_EVENT_CONNECT_RETRIED); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 36; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_3, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 36; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":37
 * EVENT_CONNECT_DELAYED = ZMQ_EVENT_CONNECT_DELAYED
 * EVENT_CONNECT_RETRIED = ZMQ_EVENT_CONNECT_RETRIED
 * EVENT_LISTENING = ZMQ_EVENT_LISTENING             # <<<<<<<<<<<<<<
 * EVENT_BIND_FAILED = ZMQ_EVENT_BIND_FAILED
 * EVENT_ACCEPTED = ZMQ_EVENT_ACCEPTED
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_EVENT_LISTENING); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 37; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__EVENT_LISTENING, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 37; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":38
 * EVENT_CONNECT_RETRIED = ZMQ_EVENT_CONNECT_RETRIED
 * EVENT_LISTENING = ZMQ_EVENT_LISTENING
 * EVENT_BIND_FAILED = ZMQ_EVENT_BIND_FAILED             # <<<<<<<<<<<<<<
 * EVENT_ACCEPTED = ZMQ_EVENT_ACCEPTED
 * EVENT_ACCEPT_FAILED = ZMQ_EVENT_ACCEPT_FAILED
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_EVENT_BIND_FAILED); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 38; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__EVENT_BIND_FAILED, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 38; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":39
 * EVENT_LISTENING = ZMQ_EVENT_LISTENING
 * EVENT_BIND_FAILED = ZMQ_EVENT_BIND_FAILED
 * EVENT_ACCEPTED = ZMQ_EVENT_ACCEPTED             # <<<<<<<<<<<<<<
 * EVENT_ACCEPT_FAILED = ZMQ_EVENT_ACCEPT_FAILED
 * EVENT_CLOSED = ZMQ_EVENT_CLOSED
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_EVENT_ACCEPTED); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 39; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__EVENT_ACCEPTED, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 39; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":40
 * EVENT_BIND_FAILED = ZMQ_EVENT_BIND_FAILED
 * EVENT_ACCEPTED = ZMQ_EVENT_ACCEPTED
 * EVENT_ACCEPT_FAILED = ZMQ_EVENT_ACCEPT_FAILED             # <<<<<<<<<<<<<<
 * EVENT_CLOSED = ZMQ_EVENT_CLOSED
 * EVENT_CLOSE_FAILED = ZMQ_EVENT_CLOSE_FAILED
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_EVENT_ACCEPT_FAILED); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 40; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__EVENT_ACCEPT_FAILED, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 40; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":41
 * EVENT_ACCEPTED = ZMQ_EVENT_ACCEPTED
 * EVENT_ACCEPT_FAILED = ZMQ_EVENT_ACCEPT_FAILED
 * EVENT_CLOSED = ZMQ_EVENT_CLOSED             # <<<<<<<<<<<<<<
 * EVENT_CLOSE_FAILED = ZMQ_EVENT_CLOSE_FAILED
 * EVENT_DISCONNECTED = ZMQ_EVENT_DISCONNECTED
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_EVENT_CLOSED); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 41; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__EVENT_CLOSED, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 41; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":42
 * EVENT_ACCEPT_FAILED = ZMQ_EVENT_ACCEPT_FAILED
 * EVENT_CLOSED = ZMQ_EVENT_CLOSED
 * EVENT_CLOSE_FAILED = ZMQ_EVENT_CLOSE_FAILED             # <<<<<<<<<<<<<<
 * EVENT_DISCONNECTED = ZMQ_EVENT_DISCONNECTED
 * EVENT_ALL = ZMQ_EVENT_ALL
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_EVENT_CLOSE_FAILED); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 42; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__EVENT_CLOSE_FAILED, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 42; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":43
 * EVENT_CLOSED = ZMQ_EVENT_CLOSED
 * EVENT_CLOSE_FAILED = ZMQ_EVENT_CLOSE_FAILED
 * EVENT_DISCONNECTED = ZMQ_EVENT_DISCONNECTED             # <<<<<<<<<<<<<<
 * EVENT_ALL = ZMQ_EVENT_ALL
 * EVENT_MONITOR_STOPPED = ZMQ_EVENT_MONITOR_STOPPED
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_EVENT_DISCONNECTED); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__EVENT_DISCONNECTED, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 43; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":44
 * EVENT_CLOSE_FAILED = ZMQ_EVENT_CLOSE_FAILED
 * EVENT_DISCONNECTED = ZMQ_EVENT_DISCONNECTED
 * EVENT_ALL = ZMQ_EVENT_ALL             # <<<<<<<<<<<<<<
 * EVENT_MONITOR_STOPPED = ZMQ_EVENT_MONITOR_STOPPED
 * globals()['NULL'] = ZMQ_NULL
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_EVENT_ALL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 44; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__EVENT_ALL, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 44; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":45
 * EVENT_DISCONNECTED = ZMQ_EVENT_DISCONNECTED
 * EVENT_ALL = ZMQ_EVENT_ALL
 * EVENT_MONITOR_STOPPED = ZMQ_EVENT_MONITOR_STOPPED             # <<<<<<<<<<<<<<
 * globals()['NULL'] = ZMQ_NULL
 * PLAIN = ZMQ_PLAIN
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_EVENT_MONITOR_STOPPED); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_4, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 45; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":46
 * EVENT_ALL = ZMQ_EVENT_ALL
 * EVENT_MONITOR_STOPPED = ZMQ_EVENT_MONITOR_STOPPED
 * globals()['NULL'] = ZMQ_NULL             # <<<<<<<<<<<<<<
 * PLAIN = ZMQ_PLAIN
 * CURVE = ZMQ_CURVE
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 46; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_Globals(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 46; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyObject_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__NULL), __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 46; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":47
 * EVENT_MONITOR_STOPPED = ZMQ_EVENT_MONITOR_STOPPED
 * globals()['NULL'] = ZMQ_NULL
 * PLAIN = ZMQ_PLAIN             # <<<<<<<<<<<<<<
 * CURVE = ZMQ_CURVE
 * EAGAIN = ZMQ_EAGAIN
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_PLAIN); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 47; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__PLAIN, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 47; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":48
 * globals()['NULL'] = ZMQ_NULL
 * PLAIN = ZMQ_PLAIN
 * CURVE = ZMQ_CURVE             # <<<<<<<<<<<<<<
 * EAGAIN = ZMQ_EAGAIN
 * EINVAL = ZMQ_EINVAL
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_CURVE); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 48; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__CURVE, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 48; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":49
 * PLAIN = ZMQ_PLAIN
 * CURVE = ZMQ_CURVE
 * EAGAIN = ZMQ_EAGAIN             # <<<<<<<<<<<<<<
 * EINVAL = ZMQ_EINVAL
 * EFAULT = ZMQ_EFAULT
 */
  __pyx_t_1 = PyInt_FromLong(EAGAIN); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 49; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__EAGAIN, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 49; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":50
 * CURVE = ZMQ_CURVE
 * EAGAIN = ZMQ_EAGAIN
 * EINVAL = ZMQ_EINVAL             # <<<<<<<<<<<<<<
 * EFAULT = ZMQ_EFAULT
 * ENOMEM = ZMQ_ENOMEM
 */
  __pyx_t_1 = PyInt_FromLong(EINVAL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 50; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__EINVAL, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 50; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":51
 * EAGAIN = ZMQ_EAGAIN
 * EINVAL = ZMQ_EINVAL
 * EFAULT = ZMQ_EFAULT             # <<<<<<<<<<<<<<
 * ENOMEM = ZMQ_ENOMEM
 * ENODEV = ZMQ_ENODEV
 */
  __pyx_t_1 = PyInt_FromLong(EFAULT); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__EFAULT, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":52
 * EINVAL = ZMQ_EINVAL
 * EFAULT = ZMQ_EFAULT
 * ENOMEM = ZMQ_ENOMEM             # <<<<<<<<<<<<<<
 * ENODEV = ZMQ_ENODEV
 * EMSGSIZE = ZMQ_EMSGSIZE
 */
  __pyx_t_1 = PyInt_FromLong(ENOMEM); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 52; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__ENOMEM, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 52; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":53
 * EFAULT = ZMQ_EFAULT
 * ENOMEM = ZMQ_ENOMEM
 * ENODEV = ZMQ_ENODEV             # <<<<<<<<<<<<<<
 * EMSGSIZE = ZMQ_EMSGSIZE
 * EAFNOSUPPORT = ZMQ_EAFNOSUPPORT
 */
  __pyx_t_1 = PyInt_FromLong(ENODEV); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 53; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__ENODEV, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 53; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":54
 * ENOMEM = ZMQ_ENOMEM
 * ENODEV = ZMQ_ENODEV
 * EMSGSIZE = ZMQ_EMSGSIZE             # <<<<<<<<<<<<<<
 * EAFNOSUPPORT = ZMQ_EAFNOSUPPORT
 * ENETUNREACH = ZMQ_ENETUNREACH
 */
  __pyx_t_1 = PyInt_FromLong(EMSGSIZE); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 54; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__EMSGSIZE, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 54; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":55
 * ENODEV = ZMQ_ENODEV
 * EMSGSIZE = ZMQ_EMSGSIZE
 * EAFNOSUPPORT = ZMQ_EAFNOSUPPORT             # <<<<<<<<<<<<<<
 * ENETUNREACH = ZMQ_ENETUNREACH
 * ECONNABORTED = ZMQ_ECONNABORTED
 */
  __pyx_t_1 = PyInt_FromLong(EAFNOSUPPORT); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 55; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__EAFNOSUPPORT, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 55; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":56
 * EMSGSIZE = ZMQ_EMSGSIZE
 * EAFNOSUPPORT = ZMQ_EAFNOSUPPORT
 * ENETUNREACH = ZMQ_ENETUNREACH             # <<<<<<<<<<<<<<
 * ECONNABORTED = ZMQ_ECONNABORTED
 * ECONNRESET = ZMQ_ECONNRESET
 */
  __pyx_t_1 = PyInt_FromLong(ENETUNREACH); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 56; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__ENETUNREACH, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 56; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":57
 * EAFNOSUPPORT = ZMQ_EAFNOSUPPORT
 * ENETUNREACH = ZMQ_ENETUNREACH
 * ECONNABORTED = ZMQ_ECONNABORTED             # <<<<<<<<<<<<<<
 * ECONNRESET = ZMQ_ECONNRESET
 * ENOTCONN = ZMQ_ENOTCONN
 */
  __pyx_t_1 = PyInt_FromLong(ECONNABORTED); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 57; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__ECONNABORTED, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 57; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":58
 * ENETUNREACH = ZMQ_ENETUNREACH
 * ECONNABORTED = ZMQ_ECONNABORTED
 * ECONNRESET = ZMQ_ECONNRESET             # <<<<<<<<<<<<<<
 * ENOTCONN = ZMQ_ENOTCONN
 * ETIMEDOUT = ZMQ_ETIMEDOUT
 */
  __pyx_t_1 = PyInt_FromLong(ECONNRESET); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 58; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__ECONNRESET, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 58; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":59
 * ECONNABORTED = ZMQ_ECONNABORTED
 * ECONNRESET = ZMQ_ECONNRESET
 * ENOTCONN = ZMQ_ENOTCONN             # <<<<<<<<<<<<<<
 * ETIMEDOUT = ZMQ_ETIMEDOUT
 * EHOSTUNREACH = ZMQ_EHOSTUNREACH
 */
  __pyx_t_1 = PyInt_FromLong(ENOTCONN); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 59; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__ENOTCONN, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 59; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":60
 * ECONNRESET = ZMQ_ECONNRESET
 * ENOTCONN = ZMQ_ENOTCONN
 * ETIMEDOUT = ZMQ_ETIMEDOUT             # <<<<<<<<<<<<<<
 * EHOSTUNREACH = ZMQ_EHOSTUNREACH
 * ENETRESET = ZMQ_ENETRESET
 */
  __pyx_t_1 = PyInt_FromLong(ETIMEDOUT); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 60; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__ETIMEDOUT, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 60; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":61
 * ENOTCONN = ZMQ_ENOTCONN
 * ETIMEDOUT = ZMQ_ETIMEDOUT
 * EHOSTUNREACH = ZMQ_EHOSTUNREACH             # <<<<<<<<<<<<<<
 * ENETRESET = ZMQ_ENETRESET
 * HAUSNUMERO = ZMQ_HAUSNUMERO
 */
  __pyx_t_1 = PyInt_FromLong(EHOSTUNREACH); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 61; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__EHOSTUNREACH, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 61; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":62
 * ETIMEDOUT = ZMQ_ETIMEDOUT
 * EHOSTUNREACH = ZMQ_EHOSTUNREACH
 * ENETRESET = ZMQ_ENETRESET             # <<<<<<<<<<<<<<
 * HAUSNUMERO = ZMQ_HAUSNUMERO
 * ENOTSUP = ZMQ_ENOTSUP
 */
  __pyx_t_1 = PyInt_FromLong(ENETRESET); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__ENETRESET, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":63
 * EHOSTUNREACH = ZMQ_EHOSTUNREACH
 * ENETRESET = ZMQ_ENETRESET
 * HAUSNUMERO = ZMQ_HAUSNUMERO             # <<<<<<<<<<<<<<
 * ENOTSUP = ZMQ_ENOTSUP
 * EPROTONOSUPPORT = ZMQ_EPROTONOSUPPORT
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_HAUSNUMERO); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 63; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__HAUSNUMERO, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 63; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":64
 * ENETRESET = ZMQ_ENETRESET
 * HAUSNUMERO = ZMQ_HAUSNUMERO
 * ENOTSUP = ZMQ_ENOTSUP             # <<<<<<<<<<<<<<
 * EPROTONOSUPPORT = ZMQ_EPROTONOSUPPORT
 * ENOBUFS = ZMQ_ENOBUFS
 */
  __pyx_t_1 = PyInt_FromLong(ENOTSUP); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 64; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__ENOTSUP, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 64; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":65
 * HAUSNUMERO = ZMQ_HAUSNUMERO
 * ENOTSUP = ZMQ_ENOTSUP
 * EPROTONOSUPPORT = ZMQ_EPROTONOSUPPORT             # <<<<<<<<<<<<<<
 * ENOBUFS = ZMQ_ENOBUFS
 * ENETDOWN = ZMQ_ENETDOWN
 */
  __pyx_t_1 = PyInt_FromLong(EPROTONOSUPPORT); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__EPROTONOSUPPORT, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":66
 * ENOTSUP = ZMQ_ENOTSUP
 * EPROTONOSUPPORT = ZMQ_EPROTONOSUPPORT
 * ENOBUFS = ZMQ_ENOBUFS             # <<<<<<<<<<<<<<
 * ENETDOWN = ZMQ_ENETDOWN
 * EADDRINUSE = ZMQ_EADDRINUSE
 */
  __pyx_t_1 = PyInt_FromLong(ENOBUFS); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__ENOBUFS, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":67
 * EPROTONOSUPPORT = ZMQ_EPROTONOSUPPORT
 * ENOBUFS = ZMQ_ENOBUFS
 * ENETDOWN = ZMQ_ENETDOWN             # <<<<<<<<<<<<<<
 * EADDRINUSE = ZMQ_EADDRINUSE
 * EADDRNOTAVAIL = ZMQ_EADDRNOTAVAIL
 */
  __pyx_t_1 = PyInt_FromLong(ENETDOWN); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__ENETDOWN, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":68
 * ENOBUFS = ZMQ_ENOBUFS
 * ENETDOWN = ZMQ_ENETDOWN
 * EADDRINUSE = ZMQ_EADDRINUSE             # <<<<<<<<<<<<<<
 * EADDRNOTAVAIL = ZMQ_EADDRNOTAVAIL
 * ECONNREFUSED = ZMQ_ECONNREFUSED
 */
  __pyx_t_1 = PyInt_FromLong(EADDRINUSE); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 68; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__EADDRINUSE, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 68; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":69
 * ENETDOWN = ZMQ_ENETDOWN
 * EADDRINUSE = ZMQ_EADDRINUSE
 * EADDRNOTAVAIL = ZMQ_EADDRNOTAVAIL             # <<<<<<<<<<<<<<
 * ECONNREFUSED = ZMQ_ECONNREFUSED
 * EINPROGRESS = ZMQ_EINPROGRESS
 */
  __pyx_t_1 = PyInt_FromLong(EADDRNOTAVAIL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 69; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__EADDRNOTAVAIL, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 69; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":70
 * EADDRINUSE = ZMQ_EADDRINUSE
 * EADDRNOTAVAIL = ZMQ_EADDRNOTAVAIL
 * ECONNREFUSED = ZMQ_ECONNREFUSED             # <<<<<<<<<<<<<<
 * EINPROGRESS = ZMQ_EINPROGRESS
 * ENOTSOCK = ZMQ_ENOTSOCK
 */
  __pyx_t_1 = PyInt_FromLong(ECONNREFUSED); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 70; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__ECONNREFUSED, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 70; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":71
 * EADDRNOTAVAIL = ZMQ_EADDRNOTAVAIL
 * ECONNREFUSED = ZMQ_ECONNREFUSED
 * EINPROGRESS = ZMQ_EINPROGRESS             # <<<<<<<<<<<<<<
 * ENOTSOCK = ZMQ_ENOTSOCK
 * EFSM = ZMQ_EFSM
 */
  __pyx_t_1 = PyInt_FromLong(EINPROGRESS); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 71; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__EINPROGRESS, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 71; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":72
 * ECONNREFUSED = ZMQ_ECONNREFUSED
 * EINPROGRESS = ZMQ_EINPROGRESS
 * ENOTSOCK = ZMQ_ENOTSOCK             # <<<<<<<<<<<<<<
 * EFSM = ZMQ_EFSM
 * ENOCOMPATPROTO = ZMQ_ENOCOMPATPROTO
 */
  __pyx_t_1 = PyInt_FromLong(ENOTSOCK); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 72; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__ENOTSOCK, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 72; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":73
 * EINPROGRESS = ZMQ_EINPROGRESS
 * ENOTSOCK = ZMQ_ENOTSOCK
 * EFSM = ZMQ_EFSM             # <<<<<<<<<<<<<<
 * ENOCOMPATPROTO = ZMQ_ENOCOMPATPROTO
 * ETERM = ZMQ_ETERM
 */
  __pyx_t_1 = PyInt_FromLong(EFSM); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 73; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__EFSM, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 73; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":74
 * ENOTSOCK = ZMQ_ENOTSOCK
 * EFSM = ZMQ_EFSM
 * ENOCOMPATPROTO = ZMQ_ENOCOMPATPROTO             # <<<<<<<<<<<<<<
 * ETERM = ZMQ_ETERM
 * EMTHREAD = ZMQ_EMTHREAD
 */
  __pyx_t_1 = PyInt_FromLong(ENOCOMPATPROTO); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 74; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__ENOCOMPATPROTO, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 74; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":75
 * EFSM = ZMQ_EFSM
 * ENOCOMPATPROTO = ZMQ_ENOCOMPATPROTO
 * ETERM = ZMQ_ETERM             # <<<<<<<<<<<<<<
 * EMTHREAD = ZMQ_EMTHREAD
 * IO_THREADS = ZMQ_IO_THREADS
 */
  __pyx_t_1 = PyInt_FromLong(ETERM); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 75; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__ETERM, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 75; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":76
 * ENOCOMPATPROTO = ZMQ_ENOCOMPATPROTO
 * ETERM = ZMQ_ETERM
 * EMTHREAD = ZMQ_EMTHREAD             # <<<<<<<<<<<<<<
 * IO_THREADS = ZMQ_IO_THREADS
 * MAX_SOCKETS = ZMQ_MAX_SOCKETS
 */
  __pyx_t_1 = PyInt_FromLong(EMTHREAD); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 76; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__EMTHREAD, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 76; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":77
 * ETERM = ZMQ_ETERM
 * EMTHREAD = ZMQ_EMTHREAD
 * IO_THREADS = ZMQ_IO_THREADS             # <<<<<<<<<<<<<<
 * MAX_SOCKETS = ZMQ_MAX_SOCKETS
 * MORE = ZMQ_MORE
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_IO_THREADS); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 77; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__IO_THREADS, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 77; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":78
 * EMTHREAD = ZMQ_EMTHREAD
 * IO_THREADS = ZMQ_IO_THREADS
 * MAX_SOCKETS = ZMQ_MAX_SOCKETS             # <<<<<<<<<<<<<<
 * MORE = ZMQ_MORE
 * IDENTITY = ZMQ_IDENTITY
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_MAX_SOCKETS); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__MAX_SOCKETS, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":79
 * IO_THREADS = ZMQ_IO_THREADS
 * MAX_SOCKETS = ZMQ_MAX_SOCKETS
 * MORE = ZMQ_MORE             # <<<<<<<<<<<<<<
 * IDENTITY = ZMQ_IDENTITY
 * SUBSCRIBE = ZMQ_SUBSCRIBE
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_MORE); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 79; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__MORE, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 79; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":80
 * MAX_SOCKETS = ZMQ_MAX_SOCKETS
 * MORE = ZMQ_MORE
 * IDENTITY = ZMQ_IDENTITY             # <<<<<<<<<<<<<<
 * SUBSCRIBE = ZMQ_SUBSCRIBE
 * UNSUBSCRIBE = ZMQ_UNSUBSCRIBE
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_IDENTITY); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 80; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__IDENTITY, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 80; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":81
 * MORE = ZMQ_MORE
 * IDENTITY = ZMQ_IDENTITY
 * SUBSCRIBE = ZMQ_SUBSCRIBE             # <<<<<<<<<<<<<<
 * UNSUBSCRIBE = ZMQ_UNSUBSCRIBE
 * LAST_ENDPOINT = ZMQ_LAST_ENDPOINT
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_SUBSCRIBE); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 81; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__SUBSCRIBE, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 81; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":82
 * IDENTITY = ZMQ_IDENTITY
 * SUBSCRIBE = ZMQ_SUBSCRIBE
 * UNSUBSCRIBE = ZMQ_UNSUBSCRIBE             # <<<<<<<<<<<<<<
 * LAST_ENDPOINT = ZMQ_LAST_ENDPOINT
 * TCP_ACCEPT_FILTER = ZMQ_TCP_ACCEPT_FILTER
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_UNSUBSCRIBE); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 82; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__UNSUBSCRIBE, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 82; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":83
 * SUBSCRIBE = ZMQ_SUBSCRIBE
 * UNSUBSCRIBE = ZMQ_UNSUBSCRIBE
 * LAST_ENDPOINT = ZMQ_LAST_ENDPOINT             # <<<<<<<<<<<<<<
 * TCP_ACCEPT_FILTER = ZMQ_TCP_ACCEPT_FILTER
 * PLAIN_USERNAME = ZMQ_PLAIN_USERNAME
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_LAST_ENDPOINT); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 83; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__LAST_ENDPOINT, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 83; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":84
 * UNSUBSCRIBE = ZMQ_UNSUBSCRIBE
 * LAST_ENDPOINT = ZMQ_LAST_ENDPOINT
 * TCP_ACCEPT_FILTER = ZMQ_TCP_ACCEPT_FILTER             # <<<<<<<<<<<<<<
 * PLAIN_USERNAME = ZMQ_PLAIN_USERNAME
 * PLAIN_PASSWORD = ZMQ_PLAIN_PASSWORD
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_TCP_ACCEPT_FILTER); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 84; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__TCP_ACCEPT_FILTER, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 84; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":85
 * LAST_ENDPOINT = ZMQ_LAST_ENDPOINT
 * TCP_ACCEPT_FILTER = ZMQ_TCP_ACCEPT_FILTER
 * PLAIN_USERNAME = ZMQ_PLAIN_USERNAME             # <<<<<<<<<<<<<<
 * PLAIN_PASSWORD = ZMQ_PLAIN_PASSWORD
 * CURVE_PUBLICKEY = ZMQ_CURVE_PUBLICKEY
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_PLAIN_USERNAME); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 85; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__PLAIN_USERNAME, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 85; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":86
 * TCP_ACCEPT_FILTER = ZMQ_TCP_ACCEPT_FILTER
 * PLAIN_USERNAME = ZMQ_PLAIN_USERNAME
 * PLAIN_PASSWORD = ZMQ_PLAIN_PASSWORD             # <<<<<<<<<<<<<<
 * CURVE_PUBLICKEY = ZMQ_CURVE_PUBLICKEY
 * CURVE_SECRETKEY = ZMQ_CURVE_SECRETKEY
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_PLAIN_PASSWORD); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 86; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__PLAIN_PASSWORD, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 86; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":87
 * PLAIN_USERNAME = ZMQ_PLAIN_USERNAME
 * PLAIN_PASSWORD = ZMQ_PLAIN_PASSWORD
 * CURVE_PUBLICKEY = ZMQ_CURVE_PUBLICKEY             # <<<<<<<<<<<<<<
 * CURVE_SECRETKEY = ZMQ_CURVE_SECRETKEY
 * CURVE_SERVERKEY = ZMQ_CURVE_SERVERKEY
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_CURVE_PUBLICKEY); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 87; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__CURVE_PUBLICKEY, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 87; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":88
 * PLAIN_PASSWORD = ZMQ_PLAIN_PASSWORD
 * CURVE_PUBLICKEY = ZMQ_CURVE_PUBLICKEY
 * CURVE_SECRETKEY = ZMQ_CURVE_SECRETKEY             # <<<<<<<<<<<<<<
 * CURVE_SERVERKEY = ZMQ_CURVE_SERVERKEY
 * ZAP_DOMAIN = ZMQ_ZAP_DOMAIN
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_CURVE_SECRETKEY); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 88; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__CURVE_SECRETKEY, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 88; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":89
 * CURVE_PUBLICKEY = ZMQ_CURVE_PUBLICKEY
 * CURVE_SECRETKEY = ZMQ_CURVE_SECRETKEY
 * CURVE_SERVERKEY = ZMQ_CURVE_SERVERKEY             # <<<<<<<<<<<<<<
 * ZAP_DOMAIN = ZMQ_ZAP_DOMAIN
 * RECONNECT_IVL_MAX = ZMQ_RECONNECT_IVL_MAX
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_CURVE_SERVERKEY); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 89; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__CURVE_SERVERKEY, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 89; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":90
 * CURVE_SECRETKEY = ZMQ_CURVE_SECRETKEY
 * CURVE_SERVERKEY = ZMQ_CURVE_SERVERKEY
 * ZAP_DOMAIN = ZMQ_ZAP_DOMAIN             # <<<<<<<<<<<<<<
 * RECONNECT_IVL_MAX = ZMQ_RECONNECT_IVL_MAX
 * SNDTIMEO = ZMQ_SNDTIMEO
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_ZAP_DOMAIN); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 90; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__ZAP_DOMAIN, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 90; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":91
 * CURVE_SERVERKEY = ZMQ_CURVE_SERVERKEY
 * ZAP_DOMAIN = ZMQ_ZAP_DOMAIN
 * RECONNECT_IVL_MAX = ZMQ_RECONNECT_IVL_MAX             # <<<<<<<<<<<<<<
 * SNDTIMEO = ZMQ_SNDTIMEO
 * RCVTIMEO = ZMQ_RCVTIMEO
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_RECONNECT_IVL_MAX); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 91; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__RECONNECT_IVL_MAX, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 91; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":92
 * ZAP_DOMAIN = ZMQ_ZAP_DOMAIN
 * RECONNECT_IVL_MAX = ZMQ_RECONNECT_IVL_MAX
 * SNDTIMEO = ZMQ_SNDTIMEO             # <<<<<<<<<<<<<<
 * RCVTIMEO = ZMQ_RCVTIMEO
 * SNDHWM = ZMQ_SNDHWM
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_SNDTIMEO); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 92; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__SNDTIMEO, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 92; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":93
 * RECONNECT_IVL_MAX = ZMQ_RECONNECT_IVL_MAX
 * SNDTIMEO = ZMQ_SNDTIMEO
 * RCVTIMEO = ZMQ_RCVTIMEO             # <<<<<<<<<<<<<<
 * SNDHWM = ZMQ_SNDHWM
 * RCVHWM = ZMQ_RCVHWM
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_RCVTIMEO); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 93; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__RCVTIMEO, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 93; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":94
 * SNDTIMEO = ZMQ_SNDTIMEO
 * RCVTIMEO = ZMQ_RCVTIMEO
 * SNDHWM = ZMQ_SNDHWM             # <<<<<<<<<<<<<<
 * RCVHWM = ZMQ_RCVHWM
 * MULTICAST_HOPS = ZMQ_MULTICAST_HOPS
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_SNDHWM); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 94; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__SNDHWM, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 94; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":95
 * RCVTIMEO = ZMQ_RCVTIMEO
 * SNDHWM = ZMQ_SNDHWM
 * RCVHWM = ZMQ_RCVHWM             # <<<<<<<<<<<<<<
 * MULTICAST_HOPS = ZMQ_MULTICAST_HOPS
 * IPV4ONLY = ZMQ_IPV4ONLY
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_RCVHWM); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 95; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__RCVHWM, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 95; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":96
 * SNDHWM = ZMQ_SNDHWM
 * RCVHWM = ZMQ_RCVHWM
 * MULTICAST_HOPS = ZMQ_MULTICAST_HOPS             # <<<<<<<<<<<<<<
 * IPV4ONLY = ZMQ_IPV4ONLY
 * ROUTER_BEHAVIOR = ZMQ_ROUTER_BEHAVIOR
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_MULTICAST_HOPS); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 96; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__MULTICAST_HOPS, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 96; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":97
 * RCVHWM = ZMQ_RCVHWM
 * MULTICAST_HOPS = ZMQ_MULTICAST_HOPS
 * IPV4ONLY = ZMQ_IPV4ONLY             # <<<<<<<<<<<<<<
 * ROUTER_BEHAVIOR = ZMQ_ROUTER_BEHAVIOR
 * TCP_KEEPALIVE = ZMQ_TCP_KEEPALIVE
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_IPV4ONLY); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 97; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__IPV4ONLY, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 97; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":98
 * MULTICAST_HOPS = ZMQ_MULTICAST_HOPS
 * IPV4ONLY = ZMQ_IPV4ONLY
 * ROUTER_BEHAVIOR = ZMQ_ROUTER_BEHAVIOR             # <<<<<<<<<<<<<<
 * TCP_KEEPALIVE = ZMQ_TCP_KEEPALIVE
 * TCP_KEEPALIVE_CNT = ZMQ_TCP_KEEPALIVE_CNT
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_ROUTER_BEHAVIOR); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 98; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__ROUTER_BEHAVIOR, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 98; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":99
 * IPV4ONLY = ZMQ_IPV4ONLY
 * ROUTER_BEHAVIOR = ZMQ_ROUTER_BEHAVIOR
 * TCP_KEEPALIVE = ZMQ_TCP_KEEPALIVE             # <<<<<<<<<<<<<<
 * TCP_KEEPALIVE_CNT = ZMQ_TCP_KEEPALIVE_CNT
 * TCP_KEEPALIVE_IDLE = ZMQ_TCP_KEEPALIVE_IDLE
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_TCP_KEEPALIVE); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 99; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__TCP_KEEPALIVE, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 99; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":100
 * ROUTER_BEHAVIOR = ZMQ_ROUTER_BEHAVIOR
 * TCP_KEEPALIVE = ZMQ_TCP_KEEPALIVE
 * TCP_KEEPALIVE_CNT = ZMQ_TCP_KEEPALIVE_CNT             # <<<<<<<<<<<<<<
 * TCP_KEEPALIVE_IDLE = ZMQ_TCP_KEEPALIVE_IDLE
 * TCP_KEEPALIVE_INTVL = ZMQ_TCP_KEEPALIVE_INTVL
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_TCP_KEEPALIVE_CNT); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 100; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__TCP_KEEPALIVE_CNT, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 100; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":101
 * TCP_KEEPALIVE = ZMQ_TCP_KEEPALIVE
 * TCP_KEEPALIVE_CNT = ZMQ_TCP_KEEPALIVE_CNT
 * TCP_KEEPALIVE_IDLE = ZMQ_TCP_KEEPALIVE_IDLE             # <<<<<<<<<<<<<<
 * TCP_KEEPALIVE_INTVL = ZMQ_TCP_KEEPALIVE_INTVL
 * DELAY_ATTACH_ON_CONNECT = ZMQ_DELAY_ATTACH_ON_CONNECT
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_TCP_KEEPALIVE_IDLE); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 101; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__TCP_KEEPALIVE_IDLE, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 101; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":102
 * TCP_KEEPALIVE_CNT = ZMQ_TCP_KEEPALIVE_CNT
 * TCP_KEEPALIVE_IDLE = ZMQ_TCP_KEEPALIVE_IDLE
 * TCP_KEEPALIVE_INTVL = ZMQ_TCP_KEEPALIVE_INTVL             # <<<<<<<<<<<<<<
 * DELAY_ATTACH_ON_CONNECT = ZMQ_DELAY_ATTACH_ON_CONNECT
 * XPUB_VERBOSE = ZMQ_XPUB_VERBOSE
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_TCP_KEEPALIVE_INTVL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__TCP_KEEPALIVE_INTVL, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":103
 * TCP_KEEPALIVE_IDLE = ZMQ_TCP_KEEPALIVE_IDLE
 * TCP_KEEPALIVE_INTVL = ZMQ_TCP_KEEPALIVE_INTVL
 * DELAY_ATTACH_ON_CONNECT = ZMQ_DELAY_ATTACH_ON_CONNECT             # <<<<<<<<<<<<<<
 * XPUB_VERBOSE = ZMQ_XPUB_VERBOSE
 * FD = ZMQ_FD
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_DELAY_ATTACH_ON_CONNECT); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_5, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":104
 * TCP_KEEPALIVE_INTVL = ZMQ_TCP_KEEPALIVE_INTVL
 * DELAY_ATTACH_ON_CONNECT = ZMQ_DELAY_ATTACH_ON_CONNECT
 * XPUB_VERBOSE = ZMQ_XPUB_VERBOSE             # <<<<<<<<<<<<<<
 * FD = ZMQ_FD
 * EVENTS = ZMQ_EVENTS
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_XPUB_VERBOSE); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 104; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__XPUB_VERBOSE, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 104; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":105
 * DELAY_ATTACH_ON_CONNECT = ZMQ_DELAY_ATTACH_ON_CONNECT
 * XPUB_VERBOSE = ZMQ_XPUB_VERBOSE
 * FD = ZMQ_FD             # <<<<<<<<<<<<<<
 * EVENTS = ZMQ_EVENTS
 * TYPE = ZMQ_TYPE
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_FD); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__FD, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":106
 * XPUB_VERBOSE = ZMQ_XPUB_VERBOSE
 * FD = ZMQ_FD
 * EVENTS = ZMQ_EVENTS             # <<<<<<<<<<<<<<
 * TYPE = ZMQ_TYPE
 * LINGER = ZMQ_LINGER
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_EVENTS); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 106; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__EVENTS, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 106; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":107
 * FD = ZMQ_FD
 * EVENTS = ZMQ_EVENTS
 * TYPE = ZMQ_TYPE             # <<<<<<<<<<<<<<
 * LINGER = ZMQ_LINGER
 * RECONNECT_IVL = ZMQ_RECONNECT_IVL
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_TYPE); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__TYPE, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":108
 * EVENTS = ZMQ_EVENTS
 * TYPE = ZMQ_TYPE
 * LINGER = ZMQ_LINGER             # <<<<<<<<<<<<<<
 * RECONNECT_IVL = ZMQ_RECONNECT_IVL
 * BACKLOG = ZMQ_BACKLOG
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_LINGER); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 108; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__LINGER, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 108; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":109
 * TYPE = ZMQ_TYPE
 * LINGER = ZMQ_LINGER
 * RECONNECT_IVL = ZMQ_RECONNECT_IVL             # <<<<<<<<<<<<<<
 * BACKLOG = ZMQ_BACKLOG
 * ROUTER_MANDATORY = ZMQ_ROUTER_MANDATORY
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_RECONNECT_IVL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 109; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__RECONNECT_IVL, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 109; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":110
 * LINGER = ZMQ_LINGER
 * RECONNECT_IVL = ZMQ_RECONNECT_IVL
 * BACKLOG = ZMQ_BACKLOG             # <<<<<<<<<<<<<<
 * ROUTER_MANDATORY = ZMQ_ROUTER_MANDATORY
 * FAIL_UNROUTABLE = ZMQ_FAIL_UNROUTABLE
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_BACKLOG); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 110; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__BACKLOG, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 110; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":111
 * RECONNECT_IVL = ZMQ_RECONNECT_IVL
 * BACKLOG = ZMQ_BACKLOG
 * ROUTER_MANDATORY = ZMQ_ROUTER_MANDATORY             # <<<<<<<<<<<<<<
 * FAIL_UNROUTABLE = ZMQ_FAIL_UNROUTABLE
 * ROUTER_RAW = ZMQ_ROUTER_RAW
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_ROUTER_MANDATORY); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 111; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__ROUTER_MANDATORY, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 111; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":112
 * BACKLOG = ZMQ_BACKLOG
 * ROUTER_MANDATORY = ZMQ_ROUTER_MANDATORY
 * FAIL_UNROUTABLE = ZMQ_FAIL_UNROUTABLE             # <<<<<<<<<<<<<<
 * ROUTER_RAW = ZMQ_ROUTER_RAW
 * IMMEDIATE = ZMQ_IMMEDIATE
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_FAIL_UNROUTABLE); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 112; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__FAIL_UNROUTABLE, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 112; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":113
 * ROUTER_MANDATORY = ZMQ_ROUTER_MANDATORY
 * FAIL_UNROUTABLE = ZMQ_FAIL_UNROUTABLE
 * ROUTER_RAW = ZMQ_ROUTER_RAW             # <<<<<<<<<<<<<<
 * IMMEDIATE = ZMQ_IMMEDIATE
 * IPV6 = ZMQ_IPV6
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_ROUTER_RAW); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 113; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__ROUTER_RAW, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 113; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":114
 * FAIL_UNROUTABLE = ZMQ_FAIL_UNROUTABLE
 * ROUTER_RAW = ZMQ_ROUTER_RAW
 * IMMEDIATE = ZMQ_IMMEDIATE             # <<<<<<<<<<<<<<
 * IPV6 = ZMQ_IPV6
 * MECHANISM = ZMQ_MECHANISM
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_IMMEDIATE); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 114; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__IMMEDIATE, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 114; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":115
 * ROUTER_RAW = ZMQ_ROUTER_RAW
 * IMMEDIATE = ZMQ_IMMEDIATE
 * IPV6 = ZMQ_IPV6             # <<<<<<<<<<<<<<
 * MECHANISM = ZMQ_MECHANISM
 * PLAIN_SERVER = ZMQ_PLAIN_SERVER
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_IPV6); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__IPV6, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":116
 * IMMEDIATE = ZMQ_IMMEDIATE
 * IPV6 = ZMQ_IPV6
 * MECHANISM = ZMQ_MECHANISM             # <<<<<<<<<<<<<<
 * PLAIN_SERVER = ZMQ_PLAIN_SERVER
 * CURVE_SERVER = ZMQ_CURVE_SERVER
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_MECHANISM); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 116; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__MECHANISM, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 116; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":117
 * IPV6 = ZMQ_IPV6
 * MECHANISM = ZMQ_MECHANISM
 * PLAIN_SERVER = ZMQ_PLAIN_SERVER             # <<<<<<<<<<<<<<
 * CURVE_SERVER = ZMQ_CURVE_SERVER
 * PROBE_ROUTER = ZMQ_PROBE_ROUTER
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_PLAIN_SERVER); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 117; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__PLAIN_SERVER, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 117; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":118
 * MECHANISM = ZMQ_MECHANISM
 * PLAIN_SERVER = ZMQ_PLAIN_SERVER
 * CURVE_SERVER = ZMQ_CURVE_SERVER             # <<<<<<<<<<<<<<
 * PROBE_ROUTER = ZMQ_PROBE_ROUTER
 * REQ_RELAXED = ZMQ_REQ_RELAXED
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_CURVE_SERVER); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 118; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__CURVE_SERVER, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 118; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":119
 * PLAIN_SERVER = ZMQ_PLAIN_SERVER
 * CURVE_SERVER = ZMQ_CURVE_SERVER
 * PROBE_ROUTER = ZMQ_PROBE_ROUTER             # <<<<<<<<<<<<<<
 * REQ_RELAXED = ZMQ_REQ_RELAXED
 * REQ_CORRELATE = ZMQ_REQ_CORRELATE
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_PROBE_ROUTER); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 119; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__PROBE_ROUTER, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 119; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":120
 * CURVE_SERVER = ZMQ_CURVE_SERVER
 * PROBE_ROUTER = ZMQ_PROBE_ROUTER
 * REQ_RELAXED = ZMQ_REQ_RELAXED             # <<<<<<<<<<<<<<
 * REQ_CORRELATE = ZMQ_REQ_CORRELATE
 * CONFLATE = ZMQ_CONFLATE
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_REQ_RELAXED); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 120; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__REQ_RELAXED, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 120; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":121
 * PROBE_ROUTER = ZMQ_PROBE_ROUTER
 * REQ_RELAXED = ZMQ_REQ_RELAXED
 * REQ_CORRELATE = ZMQ_REQ_CORRELATE             # <<<<<<<<<<<<<<
 * CONFLATE = ZMQ_CONFLATE
 * AFFINITY = ZMQ_AFFINITY
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_REQ_CORRELATE); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 121; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__REQ_CORRELATE, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 121; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":122
 * REQ_RELAXED = ZMQ_REQ_RELAXED
 * REQ_CORRELATE = ZMQ_REQ_CORRELATE
 * CONFLATE = ZMQ_CONFLATE             # <<<<<<<<<<<<<<
 * AFFINITY = ZMQ_AFFINITY
 * MAXMSGSIZE = ZMQ_MAXMSGSIZE
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_CONFLATE); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 122; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__CONFLATE, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 122; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":123
 * REQ_CORRELATE = ZMQ_REQ_CORRELATE
 * CONFLATE = ZMQ_CONFLATE
 * AFFINITY = ZMQ_AFFINITY             # <<<<<<<<<<<<<<
 * MAXMSGSIZE = ZMQ_MAXMSGSIZE
 * HWM = ZMQ_HWM
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_AFFINITY); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 123; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__AFFINITY, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 123; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":124
 * CONFLATE = ZMQ_CONFLATE
 * AFFINITY = ZMQ_AFFINITY
 * MAXMSGSIZE = ZMQ_MAXMSGSIZE             # <<<<<<<<<<<<<<
 * HWM = ZMQ_HWM
 * SWAP = ZMQ_SWAP
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_MAXMSGSIZE); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 124; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__MAXMSGSIZE, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 124; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":125
 * AFFINITY = ZMQ_AFFINITY
 * MAXMSGSIZE = ZMQ_MAXMSGSIZE
 * HWM = ZMQ_HWM             # <<<<<<<<<<<<<<
 * SWAP = ZMQ_SWAP
 * MCAST_LOOP = ZMQ_MCAST_LOOP
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_HWM); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 125; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__HWM, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 125; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":126
 * MAXMSGSIZE = ZMQ_MAXMSGSIZE
 * HWM = ZMQ_HWM
 * SWAP = ZMQ_SWAP             # <<<<<<<<<<<<<<
 * MCAST_LOOP = ZMQ_MCAST_LOOP
 * RECOVERY_IVL_MSEC = ZMQ_RECOVERY_IVL_MSEC
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_SWAP); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 126; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__SWAP, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 126; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":127
 * HWM = ZMQ_HWM
 * SWAP = ZMQ_SWAP
 * MCAST_LOOP = ZMQ_MCAST_LOOP             # <<<<<<<<<<<<<<
 * RECOVERY_IVL_MSEC = ZMQ_RECOVERY_IVL_MSEC
 * RATE = ZMQ_RATE
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_MCAST_LOOP); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 127; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__MCAST_LOOP, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 127; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":128
 * SWAP = ZMQ_SWAP
 * MCAST_LOOP = ZMQ_MCAST_LOOP
 * RECOVERY_IVL_MSEC = ZMQ_RECOVERY_IVL_MSEC             # <<<<<<<<<<<<<<
 * RATE = ZMQ_RATE
 * RECOVERY_IVL = ZMQ_RECOVERY_IVL
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_RECOVERY_IVL_MSEC); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 128; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__RECOVERY_IVL_MSEC, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 128; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":129
 * MCAST_LOOP = ZMQ_MCAST_LOOP
 * RECOVERY_IVL_MSEC = ZMQ_RECOVERY_IVL_MSEC
 * RATE = ZMQ_RATE             # <<<<<<<<<<<<<<
 * RECOVERY_IVL = ZMQ_RECOVERY_IVL
 * SNDBUF = ZMQ_SNDBUF
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_RATE); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__RATE, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":130
 * RECOVERY_IVL_MSEC = ZMQ_RECOVERY_IVL_MSEC
 * RATE = ZMQ_RATE
 * RECOVERY_IVL = ZMQ_RECOVERY_IVL             # <<<<<<<<<<<<<<
 * SNDBUF = ZMQ_SNDBUF
 * RCVBUF = ZMQ_RCVBUF
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_RECOVERY_IVL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 130; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__RECOVERY_IVL, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 130; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":131
 * RATE = ZMQ_RATE
 * RECOVERY_IVL = ZMQ_RECOVERY_IVL
 * SNDBUF = ZMQ_SNDBUF             # <<<<<<<<<<<<<<
 * RCVBUF = ZMQ_RCVBUF
 * RCVMORE = ZMQ_RCVMORE
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_SNDBUF); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 131; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__SNDBUF, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 131; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":132
 * RECOVERY_IVL = ZMQ_RECOVERY_IVL
 * SNDBUF = ZMQ_SNDBUF
 * RCVBUF = ZMQ_RCVBUF             # <<<<<<<<<<<<<<
 * RCVMORE = ZMQ_RCVMORE
 * 
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_RCVBUF); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__RCVBUF, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":133
 * SNDBUF = ZMQ_SNDBUF
 * RCVBUF = ZMQ_RCVBUF
 * RCVMORE = ZMQ_RCVMORE             # <<<<<<<<<<<<<<
 * 
 * #-----------------------------------------------------------------------------
 */
  __pyx_t_1 = PyInt_FromLong(ZMQ_RCVMORE); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s__RCVMORE, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "/private/tmp/pyzmq/zmq/backend/cython/constants.pxi":138
 * # Symbols to export
 * #-----------------------------------------------------------------------------
 * __all__ = [             # <<<<<<<<<<<<<<
 *   "VERSION",
 *   "VERSION_MAJOR",
 */
  __pyx_t_1 = PyList_New(129); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__VERSION));
  PyList_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_n_s__VERSION));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__VERSION));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__VERSION_MAJOR));
  PyList_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_n_s__VERSION_MAJOR));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__VERSION_MAJOR));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__VERSION_MINOR));
  PyList_SET_ITEM(__pyx_t_1, 2, ((PyObject *)__pyx_n_s__VERSION_MINOR));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__VERSION_MINOR));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__VERSION_PATCH));
  PyList_SET_ITEM(__pyx_t_1, 3, ((PyObject *)__pyx_n_s__VERSION_PATCH));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__VERSION_PATCH));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__NOBLOCK));
  PyList_SET_ITEM(__pyx_t_1, 4, ((PyObject *)__pyx_n_s__NOBLOCK));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__NOBLOCK));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__DONTWAIT));
  PyList_SET_ITEM(__pyx_t_1, 5, ((PyObject *)__pyx_n_s__DONTWAIT));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__DONTWAIT));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__POLLIN));
  PyList_SET_ITEM(__pyx_t_1, 6, ((PyObject *)__pyx_n_s__POLLIN));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__POLLIN));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__POLLOUT));
  PyList_SET_ITEM(__pyx_t_1, 7, ((PyObject *)__pyx_n_s__POLLOUT));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__POLLOUT));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__POLLERR));
  PyList_SET_ITEM(__pyx_t_1, 8, ((PyObject *)__pyx_n_s__POLLERR));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__POLLERR));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__SNDMORE));
  PyList_SET_ITEM(__pyx_t_1, 9, ((PyObject *)__pyx_n_s__SNDMORE));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__SNDMORE));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__STREAMER));
  PyList_SET_ITEM(__pyx_t_1, 10, ((PyObject *)__pyx_n_s__STREAMER));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__STREAMER));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__FORWARDER));
  PyList_SET_ITEM(__pyx_t_1, 11, ((PyObject *)__pyx_n_s__FORWARDER));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__FORWARDER));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__QUEUE));
  PyList_SET_ITEM(__pyx_t_1, 12, ((PyObject *)__pyx_n_s__QUEUE));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__QUEUE));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__IO_THREADS_DFLT));
  PyList_SET_ITEM(__pyx_t_1, 13, ((PyObject *)__pyx_n_s__IO_THREADS_DFLT));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__IO_THREADS_DFLT));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__MAX_SOCKETS_DFLT));
  PyList_SET_ITEM(__pyx_t_1, 14, ((PyObject *)__pyx_n_s__MAX_SOCKETS_DFLT));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__MAX_SOCKETS_DFLT));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__PAIR));
  PyList_SET_ITEM(__pyx_t_1, 15, ((PyObject *)__pyx_n_s__PAIR));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__PAIR));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__PUB));
  PyList_SET_ITEM(__pyx_t_1, 16, ((PyObject *)__pyx_n_s__PUB));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__PUB));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__SUB));
  PyList_SET_ITEM(__pyx_t_1, 17, ((PyObject *)__pyx_n_s__SUB));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__SUB));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__REQ));
  PyList_SET_ITEM(__pyx_t_1, 18, ((PyObject *)__pyx_n_s__REQ));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__REQ));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__REP));
  PyList_SET_ITEM(__pyx_t_1, 19, ((PyObject *)__pyx_n_s__REP));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__REP));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__DEALER));
  PyList_SET_ITEM(__pyx_t_1, 20, ((PyObject *)__pyx_n_s__DEALER));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__DEALER));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ROUTER));
  PyList_SET_ITEM(__pyx_t_1, 21, ((PyObject *)__pyx_n_s__ROUTER));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ROUTER));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__PULL));
  PyList_SET_ITEM(__pyx_t_1, 22, ((PyObject *)__pyx_n_s__PULL));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__PULL));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__PUSH));
  PyList_SET_ITEM(__pyx_t_1, 23, ((PyObject *)__pyx_n_s__PUSH));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__PUSH));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__XPUB));
  PyList_SET_ITEM(__pyx_t_1, 24, ((PyObject *)__pyx_n_s__XPUB));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__XPUB));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__XSUB));
  PyList_SET_ITEM(__pyx_t_1, 25, ((PyObject *)__pyx_n_s__XSUB));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__XSUB));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__UPSTREAM));
  PyList_SET_ITEM(__pyx_t_1, 26, ((PyObject *)__pyx_n_s__UPSTREAM));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__UPSTREAM));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__DOWNSTREAM));
  PyList_SET_ITEM(__pyx_t_1, 27, ((PyObject *)__pyx_n_s__DOWNSTREAM));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__DOWNSTREAM));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__STREAM));
  PyList_SET_ITEM(__pyx_t_1, 28, ((PyObject *)__pyx_n_s__STREAM));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__STREAM));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__EVENT_CONNECTED));
  PyList_SET_ITEM(__pyx_t_1, 29, ((PyObject *)__pyx_n_s__EVENT_CONNECTED));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__EVENT_CONNECTED));
  __Pyx_INCREF(((PyObject *)__pyx_n_s_2));
  PyList_SET_ITEM(__pyx_t_1, 30, ((PyObject *)__pyx_n_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s_2));
  __Pyx_INCREF(((PyObject *)__pyx_n_s_3));
  PyList_SET_ITEM(__pyx_t_1, 31, ((PyObject *)__pyx_n_s_3));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s_3));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__EVENT_LISTENING));
  PyList_SET_ITEM(__pyx_t_1, 32, ((PyObject *)__pyx_n_s__EVENT_LISTENING));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__EVENT_LISTENING));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__EVENT_BIND_FAILED));
  PyList_SET_ITEM(__pyx_t_1, 33, ((PyObject *)__pyx_n_s__EVENT_BIND_FAILED));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__EVENT_BIND_FAILED));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__EVENT_ACCEPTED));
  PyList_SET_ITEM(__pyx_t_1, 34, ((PyObject *)__pyx_n_s__EVENT_ACCEPTED));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__EVENT_ACCEPTED));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__EVENT_ACCEPT_FAILED));
  PyList_SET_ITEM(__pyx_t_1, 35, ((PyObject *)__pyx_n_s__EVENT_ACCEPT_FAILED));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__EVENT_ACCEPT_FAILED));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__EVENT_CLOSED));
  PyList_SET_ITEM(__pyx_t_1, 36, ((PyObject *)__pyx_n_s__EVENT_CLOSED));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__EVENT_CLOSED));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__EVENT_CLOSE_FAILED));
  PyList_SET_ITEM(__pyx_t_1, 37, ((PyObject *)__pyx_n_s__EVENT_CLOSE_FAILED));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__EVENT_CLOSE_FAILED));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__EVENT_DISCONNECTED));
  PyList_SET_ITEM(__pyx_t_1, 38, ((PyObject *)__pyx_n_s__EVENT_DISCONNECTED));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__EVENT_DISCONNECTED));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__EVENT_ALL));
  PyList_SET_ITEM(__pyx_t_1, 39, ((PyObject *)__pyx_n_s__EVENT_ALL));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__EVENT_ALL));
  __Pyx_INCREF(((PyObject *)__pyx_n_s_4));
  PyList_SET_ITEM(__pyx_t_1, 40, ((PyObject *)__pyx_n_s_4));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s_4));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__NULL));
  PyList_SET_ITEM(__pyx_t_1, 41, ((PyObject *)__pyx_n_s__NULL));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__NULL));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__PLAIN));
  PyList_SET_ITEM(__pyx_t_1, 42, ((PyObject *)__pyx_n_s__PLAIN));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__PLAIN));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__CURVE));
  PyList_SET_ITEM(__pyx_t_1, 43, ((PyObject *)__pyx_n_s__CURVE));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__CURVE));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__EAGAIN));
  PyList_SET_ITEM(__pyx_t_1, 44, ((PyObject *)__pyx_n_s__EAGAIN));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__EAGAIN));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__EINVAL));
  PyList_SET_ITEM(__pyx_t_1, 45, ((PyObject *)__pyx_n_s__EINVAL));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__EINVAL));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__EFAULT));
  PyList_SET_ITEM(__pyx_t_1, 46, ((PyObject *)__pyx_n_s__EFAULT));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__EFAULT));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ENOMEM));
  PyList_SET_ITEM(__pyx_t_1, 47, ((PyObject *)__pyx_n_s__ENOMEM));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ENOMEM));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ENODEV));
  PyList_SET_ITEM(__pyx_t_1, 48, ((PyObject *)__pyx_n_s__ENODEV));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ENODEV));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__EMSGSIZE));
  PyList_SET_ITEM(__pyx_t_1, 49, ((PyObject *)__pyx_n_s__EMSGSIZE));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__EMSGSIZE));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__EAFNOSUPPORT));
  PyList_SET_ITEM(__pyx_t_1, 50, ((PyObject *)__pyx_n_s__EAFNOSUPPORT));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__EAFNOSUPPORT));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ENETUNREACH));
  PyList_SET_ITEM(__pyx_t_1, 51, ((PyObject *)__pyx_n_s__ENETUNREACH));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ENETUNREACH));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ECONNABORTED));
  PyList_SET_ITEM(__pyx_t_1, 52, ((PyObject *)__pyx_n_s__ECONNABORTED));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ECONNABORTED));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ECONNRESET));
  PyList_SET_ITEM(__pyx_t_1, 53, ((PyObject *)__pyx_n_s__ECONNRESET));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ECONNRESET));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ENOTCONN));
  PyList_SET_ITEM(__pyx_t_1, 54, ((PyObject *)__pyx_n_s__ENOTCONN));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ENOTCONN));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ETIMEDOUT));
  PyList_SET_ITEM(__pyx_t_1, 55, ((PyObject *)__pyx_n_s__ETIMEDOUT));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ETIMEDOUT));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__EHOSTUNREACH));
  PyList_SET_ITEM(__pyx_t_1, 56, ((PyObject *)__pyx_n_s__EHOSTUNREACH));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__EHOSTUNREACH));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ENETRESET));
  PyList_SET_ITEM(__pyx_t_1, 57, ((PyObject *)__pyx_n_s__ENETRESET));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ENETRESET));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__HAUSNUMERO));
  PyList_SET_ITEM(__pyx_t_1, 58, ((PyObject *)__pyx_n_s__HAUSNUMERO));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__HAUSNUMERO));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ENOTSUP));
  PyList_SET_ITEM(__pyx_t_1, 59, ((PyObject *)__pyx_n_s__ENOTSUP));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ENOTSUP));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__EPROTONOSUPPORT));
  PyList_SET_ITEM(__pyx_t_1, 60, ((PyObject *)__pyx_n_s__EPROTONOSUPPORT));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__EPROTONOSUPPORT));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ENOBUFS));
  PyList_SET_ITEM(__pyx_t_1, 61, ((PyObject *)__pyx_n_s__ENOBUFS));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ENOBUFS));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ENETDOWN));
  PyList_SET_ITEM(__pyx_t_1, 62, ((PyObject *)__pyx_n_s__ENETDOWN));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ENETDOWN));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__EADDRINUSE));
  PyList_SET_ITEM(__pyx_t_1, 63, ((PyObject *)__pyx_n_s__EADDRINUSE));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__EADDRINUSE));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__EADDRNOTAVAIL));
  PyList_SET_ITEM(__pyx_t_1, 64, ((PyObject *)__pyx_n_s__EADDRNOTAVAIL));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__EADDRNOTAVAIL));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ECONNREFUSED));
  PyList_SET_ITEM(__pyx_t_1, 65, ((PyObject *)__pyx_n_s__ECONNREFUSED));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ECONNREFUSED));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__EINPROGRESS));
  PyList_SET_ITEM(__pyx_t_1, 66, ((PyObject *)__pyx_n_s__EINPROGRESS));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__EINPROGRESS));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ENOTSOCK));
  PyList_SET_ITEM(__pyx_t_1, 67, ((PyObject *)__pyx_n_s__ENOTSOCK));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ENOTSOCK));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__EFSM));
  PyList_SET_ITEM(__pyx_t_1, 68, ((PyObject *)__pyx_n_s__EFSM));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__EFSM));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ENOCOMPATPROTO));
  PyList_SET_ITEM(__pyx_t_1, 69, ((PyObject *)__pyx_n_s__ENOCOMPATPROTO));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ENOCOMPATPROTO));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ETERM));
  PyList_SET_ITEM(__pyx_t_1, 70, ((PyObject *)__pyx_n_s__ETERM));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ETERM));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__EMTHREAD));
  PyList_SET_ITEM(__pyx_t_1, 71, ((PyObject *)__pyx_n_s__EMTHREAD));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__EMTHREAD));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__IO_THREADS));
  PyList_SET_ITEM(__pyx_t_1, 72, ((PyObject *)__pyx_n_s__IO_THREADS));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__IO_THREADS));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__MAX_SOCKETS));
  PyList_SET_ITEM(__pyx_t_1, 73, ((PyObject *)__pyx_n_s__MAX_SOCKETS));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__MAX_SOCKETS));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__MORE));
  PyList_SET_ITEM(__pyx_t_1, 74, ((PyObject *)__pyx_n_s__MORE));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__MORE));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__IDENTITY));
  PyList_SET_ITEM(__pyx_t_1, 75, ((PyObject *)__pyx_n_s__IDENTITY));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__IDENTITY));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__SUBSCRIBE));
  PyList_SET_ITEM(__pyx_t_1, 76, ((PyObject *)__pyx_n_s__SUBSCRIBE));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__SUBSCRIBE));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__UNSUBSCRIBE));
  PyList_SET_ITEM(__pyx_t_1, 77, ((PyObject *)__pyx_n_s__UNSUBSCRIBE));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__UNSUBSCRIBE));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__LAST_ENDPOINT));
  PyList_SET_ITEM(__pyx_t_1, 78, ((PyObject *)__pyx_n_s__LAST_ENDPOINT));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__LAST_ENDPOINT));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__TCP_ACCEPT_FILTER));
  PyList_SET_ITEM(__pyx_t_1, 79, ((PyObject *)__pyx_n_s__TCP_ACCEPT_FILTER));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__TCP_ACCEPT_FILTER));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__PLAIN_USERNAME));
  PyList_SET_ITEM(__pyx_t_1, 80, ((PyObject *)__pyx_n_s__PLAIN_USERNAME));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__PLAIN_USERNAME));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__PLAIN_PASSWORD));
  PyList_SET_ITEM(__pyx_t_1, 81, ((PyObject *)__pyx_n_s__PLAIN_PASSWORD));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__PLAIN_PASSWORD));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__CURVE_PUBLICKEY));
  PyList_SET_ITEM(__pyx_t_1, 82, ((PyObject *)__pyx_n_s__CURVE_PUBLICKEY));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__CURVE_PUBLICKEY));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__CURVE_SECRETKEY));
  PyList_SET_ITEM(__pyx_t_1, 83, ((PyObject *)__pyx_n_s__CURVE_SECRETKEY));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__CURVE_SECRETKEY));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__CURVE_SERVERKEY));
  PyList_SET_ITEM(__pyx_t_1, 84, ((PyObject *)__pyx_n_s__CURVE_SERVERKEY));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__CURVE_SERVERKEY));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ZAP_DOMAIN));
  PyList_SET_ITEM(__pyx_t_1, 85, ((PyObject *)__pyx_n_s__ZAP_DOMAIN));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ZAP_DOMAIN));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__RECONNECT_IVL_MAX));
  PyList_SET_ITEM(__pyx_t_1, 86, ((PyObject *)__pyx_n_s__RECONNECT_IVL_MAX));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__RECONNECT_IVL_MAX));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__SNDTIMEO));
  PyList_SET_ITEM(__pyx_t_1, 87, ((PyObject *)__pyx_n_s__SNDTIMEO));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__SNDTIMEO));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__RCVTIMEO));
  PyList_SET_ITEM(__pyx_t_1, 88, ((PyObject *)__pyx_n_s__RCVTIMEO));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__RCVTIMEO));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__SNDHWM));
  PyList_SET_ITEM(__pyx_t_1, 89, ((PyObject *)__pyx_n_s__SNDHWM));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__SNDHWM));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__RCVHWM));
  PyList_SET_ITEM(__pyx_t_1, 90, ((PyObject *)__pyx_n_s__RCVHWM));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__RCVHWM));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__MULTICAST_HOPS));
  PyList_SET_ITEM(__pyx_t_1, 91, ((PyObject *)__pyx_n_s__MULTICAST_HOPS));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__MULTICAST_HOPS));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__IPV4ONLY));
  PyList_SET_ITEM(__pyx_t_1, 92, ((PyObject *)__pyx_n_s__IPV4ONLY));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__IPV4ONLY));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ROUTER_BEHAVIOR));
  PyList_SET_ITEM(__pyx_t_1, 93, ((PyObject *)__pyx_n_s__ROUTER_BEHAVIOR));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ROUTER_BEHAVIOR));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__TCP_KEEPALIVE));
  PyList_SET_ITEM(__pyx_t_1, 94, ((PyObject *)__pyx_n_s__TCP_KEEPALIVE));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__TCP_KEEPALIVE));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__TCP_KEEPALIVE_CNT));
  PyList_SET_ITEM(__pyx_t_1, 95, ((PyObject *)__pyx_n_s__TCP_KEEPALIVE_CNT));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__TCP_KEEPALIVE_CNT));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__TCP_KEEPALIVE_IDLE));
  PyList_SET_ITEM(__pyx_t_1, 96, ((PyObject *)__pyx_n_s__TCP_KEEPALIVE_IDLE));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__TCP_KEEPALIVE_IDLE));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__TCP_KEEPALIVE_INTVL));
  PyList_SET_ITEM(__pyx_t_1, 97, ((PyObject *)__pyx_n_s__TCP_KEEPALIVE_INTVL));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__TCP_KEEPALIVE_INTVL));
  __Pyx_INCREF(((PyObject *)__pyx_n_s_5));
  PyList_SET_ITEM(__pyx_t_1, 98, ((PyObject *)__pyx_n_s_5));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s_5));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__XPUB_VERBOSE));
  PyList_SET_ITEM(__pyx_t_1, 99, ((PyObject *)__pyx_n_s__XPUB_VERBOSE));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__XPUB_VERBOSE));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__FD));
  PyList_SET_ITEM(__pyx_t_1, 100, ((PyObject *)__pyx_n_s__FD));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__FD));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__EVENTS));
  PyList_SET_ITEM(__pyx_t_1, 101, ((PyObject *)__pyx_n_s__EVENTS));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__EVENTS));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__TYPE));
  PyList_SET_ITEM(__pyx_t_1, 102, ((PyObject *)__pyx_n_s__TYPE));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__TYPE));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__LINGER));
  PyList_SET_ITEM(__pyx_t_1, 103, ((PyObject *)__pyx_n_s__LINGER));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__LINGER));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__RECONNECT_IVL));
  PyList_SET_ITEM(__pyx_t_1, 104, ((PyObject *)__pyx_n_s__RECONNECT_IVL));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__RECONNECT_IVL));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__BACKLOG));
  PyList_SET_ITEM(__pyx_t_1, 105, ((PyObject *)__pyx_n_s__BACKLOG));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__BACKLOG));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ROUTER_MANDATORY));
  PyList_SET_ITEM(__pyx_t_1, 106, ((PyObject *)__pyx_n_s__ROUTER_MANDATORY));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ROUTER_MANDATORY));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__FAIL_UNROUTABLE));
  PyList_SET_ITEM(__pyx_t_1, 107, ((PyObject *)__pyx_n_s__FAIL_UNROUTABLE));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__FAIL_UNROUTABLE));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__ROUTER_RAW));
  PyList_SET_ITEM(__pyx_t_1, 108, ((PyObject *)__pyx_n_s__ROUTER_RAW));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__ROUTER_RAW));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__IMMEDIATE));
  PyList_SET_ITEM(__pyx_t_1, 109, ((PyObject *)__pyx_n_s__IMMEDIATE));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__IMMEDIATE));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__IPV6));
  PyList_SET_ITEM(__pyx_t_1, 110, ((PyObject *)__pyx_n_s__IPV6));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__IPV6));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__MECHANISM));
  PyList_SET_ITEM(__pyx_t_1, 111, ((PyObject *)__pyx_n_s__MECHANISM));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__MECHANISM));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__PLAIN_SERVER));
  PyList_SET_ITEM(__pyx_t_1, 112, ((PyObject *)__pyx_n_s__PLAIN_SERVER));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__PLAIN_SERVER));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__CURVE_SERVER));
  PyList_SET_ITEM(__pyx_t_1, 113, ((PyObject *)__pyx_n_s__CURVE_SERVER));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__CURVE_SERVER));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__PROBE_ROUTER));
  PyList_SET_ITEM(__pyx_t_1, 114, ((PyObject *)__pyx_n_s__PROBE_ROUTER));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__PROBE_ROUTER));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__REQ_RELAXED));
  PyList_SET_ITEM(__pyx_t_1, 115, ((PyObject *)__pyx_n_s__REQ_RELAXED));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__REQ_RELAXED));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__REQ_CORRELATE));
  PyList_SET_ITEM(__pyx_t_1, 116, ((PyObject *)__pyx_n_s__REQ_CORRELATE));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__REQ_CORRELATE));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__CONFLATE));
  PyList_SET_ITEM(__pyx_t_1, 117, ((PyObject *)__pyx_n_s__CONFLATE));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__CONFLATE));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__AFFINITY));
  PyList_SET_ITEM(__pyx_t_1, 118, ((PyObject *)__pyx_n_s__AFFINITY));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__AFFINITY));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__MAXMSGSIZE));
  PyList_SET_ITEM(__pyx_t_1, 119, ((PyObject *)__pyx_n_s__MAXMSGSIZE));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__MAXMSGSIZE));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__HWM));
  PyList_SET_ITEM(__pyx_t_1, 120, ((PyObject *)__pyx_n_s__HWM));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__HWM));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__SWAP));
  PyList_SET_ITEM(__pyx_t_1, 121, ((PyObject *)__pyx_n_s__SWAP));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__SWAP));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__MCAST_LOOP));
  PyList_SET_ITEM(__pyx_t_1, 122, ((PyObject *)__pyx_n_s__MCAST_LOOP));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__MCAST_LOOP));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__RECOVERY_IVL_MSEC));
  PyList_SET_ITEM(__pyx_t_1, 123, ((PyObject *)__pyx_n_s__RECOVERY_IVL_MSEC));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__RECOVERY_IVL_MSEC));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__RATE));
  PyList_SET_ITEM(__pyx_t_1, 124, ((PyObject *)__pyx_n_s__RATE));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__RATE));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__RECOVERY_IVL));
  PyList_SET_ITEM(__pyx_t_1, 125, ((PyObject *)__pyx_n_s__RECOVERY_IVL));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__RECOVERY_IVL));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__SNDBUF));
  PyList_SET_ITEM(__pyx_t_1, 126, ((PyObject *)__pyx_n_s__SNDBUF));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__SNDBUF));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__RCVBUF));
  PyList_SET_ITEM(__pyx_t_1, 127, ((PyObject *)__pyx_n_s__RCVBUF));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__RCVBUF));
  __Pyx_INCREF(((PyObject *)__pyx_n_s__RCVMORE));
  PyList_SET_ITEM(__pyx_t_1, 128, ((PyObject *)__pyx_n_s__RCVMORE));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__RCVMORE));
  if (PyDict_SetItem(__pyx_d, __pyx_n_s____all__, ((PyObject *)__pyx_t_1)) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;

  /* "zmq/backend/cython/constants.pyx":1
 * """0MQ Constants."""             # <<<<<<<<<<<<<<
 * 
 * #
 */
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  if (PyDict_SetItem(__pyx_d, __pyx_n_s____test__, ((PyObject *)__pyx_t_1)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  if (__pyx_m) {
    __Pyx_AddTraceback("init zmq.backend.cython.constants", __pyx_clineno, __pyx_lineno, __pyx_filename);
    Py_DECREF(__pyx_m); __pyx_m = 0;
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init zmq.backend.cython.constants");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if PY_MAJOR_VERSION < 3
  return;
  #else
  return __pyx_m;
  #endif
}

/* Runtime support code */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule((char *)modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, (char *)"RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif /* CYTHON_REFNANNY */

static PyObject* __Pyx_Globals(void) {
    Py_ssize_t i;
    PyObject *names = NULL;
    PyObject *globals = PyObject_GetAttr(__pyx_m, __pyx_n_s____dict__);
    if (!globals) {
        PyErr_SetString(PyExc_TypeError,
            "current module must have __dict__ attribute");
        goto bad;
    }
    names = PyObject_Dir(__pyx_m);
    if (!names)
        goto bad;
    for (i = PyList_GET_SIZE(names)-1; i >= 0; i--) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject* name = PySequence_GetItem(names, i);
        if (!name)
            goto bad;
#else
        PyObject* name = PyList_GET_ITEM(names, i);
#endif
        if (!PyDict_Contains(globals, name)) {
            PyObject* value = PyObject_GetAttr(__pyx_m, name);
            if (!value) {
#if CYTHON_COMPILING_IN_PYPY
                Py_DECREF(name);
#endif
                goto bad;
            }
            if (PyDict_SetItem(globals, name, value) < 0) {
#if CYTHON_COMPILING_IN_PYPY
                Py_DECREF(name);
#endif
                Py_DECREF(value);
                goto bad;
            }
        }
#if CYTHON_COMPILING_IN_PYPY
        Py_DECREF(name);
#endif
    }
    Py_DECREF(names);
    return globals;
bad:
    Py_XDECREF(names);
    Py_XDECREF(globals);
    return NULL;
}

static CYTHON_INLINE unsigned char __Pyx_PyInt_AsUnsignedChar(PyObject* x) {
    const unsigned char neg_one = (unsigned char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned char" :
                    "value too large to convert to unsigned char");
            }
            return (unsigned char)-1;
        }
        return (unsigned char)val;
    }
    return (unsigned char)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE unsigned short __Pyx_PyInt_AsUnsignedShort(PyObject* x) {
    const unsigned short neg_one = (unsigned short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned short" :
                    "value too large to convert to unsigned short");
            }
            return (unsigned short)-1;
        }
        return (unsigned short)val;
    }
    return (unsigned short)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE unsigned int __Pyx_PyInt_AsUnsignedInt(PyObject* x) {
    const unsigned int neg_one = (unsigned int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned int" :
                    "value too large to convert to unsigned int");
            }
            return (unsigned int)-1;
        }
        return (unsigned int)val;
    }
    return (unsigned int)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE char __Pyx_PyInt_AsChar(PyObject* x) {
    const char neg_one = (char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to char" :
                    "value too large to convert to char");
            }
            return (char)-1;
        }
        return (char)val;
    }
    return (char)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE short __Pyx_PyInt_AsShort(PyObject* x) {
    const short neg_one = (short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to short" :
                    "value too large to convert to short");
            }
            return (short)-1;
        }
        return (short)val;
    }
    return (short)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE int __Pyx_PyInt_AsInt(PyObject* x) {
    const int neg_one = (int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to int" :
                    "value too large to convert to int");
            }
            return (int)-1;
        }
        return (int)val;
    }
    return (int)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE signed char __Pyx_PyInt_AsSignedChar(PyObject* x) {
    const signed char neg_one = (signed char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed char" :
                    "value too large to convert to signed char");
            }
            return (signed char)-1;
        }
        return (signed char)val;
    }
    return (signed char)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE signed short __Pyx_PyInt_AsSignedShort(PyObject* x) {
    const signed short neg_one = (signed short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed short" :
                    "value too large to convert to signed short");
            }
            return (signed short)-1;
        }
        return (signed short)val;
    }
    return (signed short)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE signed int __Pyx_PyInt_AsSignedInt(PyObject* x) {
    const signed int neg_one = (signed int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed int" :
                    "value too large to convert to signed int");
            }
            return (signed int)-1;
        }
        return (signed int)val;
    }
    return (signed int)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE int __Pyx_PyInt_AsLongDouble(PyObject* x) {
    const int neg_one = (int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to int" :
                    "value too large to convert to int");
            }
            return (int)-1;
        }
        return (int)val;
    }
    return (int)__Pyx_PyInt_AsLong(x);
}

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
#include "longintrepr.h"
#endif
#endif
static CYTHON_INLINE unsigned long __Pyx_PyInt_AsUnsignedLong(PyObject* x) {
    const unsigned long neg_one = (unsigned long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to unsigned long");
            return (unsigned long)-1;
        }
        return (unsigned long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(unsigned long)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return (unsigned long) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to unsigned long");
                return (unsigned long)-1;
            }
            return (unsigned long)PyLong_AsUnsignedLong(x);
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(unsigned long)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return +(unsigned long) ((PyLongObject*)x)->ob_digit[0];
                    case -1: return -(unsigned long) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            return (unsigned long)PyLong_AsLong(x);
        }
    } else {
        unsigned long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (unsigned long)-1;
        val = __Pyx_PyInt_AsUnsignedLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
#include "longintrepr.h"
#endif
#endif
static CYTHON_INLINE unsigned PY_LONG_LONG __Pyx_PyInt_AsUnsignedLongLong(PyObject* x) {
    const unsigned PY_LONG_LONG neg_one = (unsigned PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to unsigned PY_LONG_LONG");
            return (unsigned PY_LONG_LONG)-1;
        }
        return (unsigned PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(unsigned PY_LONG_LONG)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return (unsigned PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to unsigned PY_LONG_LONG");
                return (unsigned PY_LONG_LONG)-1;
            }
            return (unsigned PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(unsigned PY_LONG_LONG)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return +(unsigned PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                    case -1: return -(unsigned PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            return (unsigned PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        unsigned PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (unsigned PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsUnsignedLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
#include "longintrepr.h"
#endif
#endif
static CYTHON_INLINE long __Pyx_PyInt_AsLong(PyObject* x) {
    const long neg_one = (long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to long");
            return (long)-1;
        }
        return (long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(long)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return (long) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to long");
                return (long)-1;
            }
            return (long)PyLong_AsUnsignedLong(x);
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(long)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return +(long) ((PyLongObject*)x)->ob_digit[0];
                    case -1: return -(long) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            return (long)PyLong_AsLong(x);
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (long)-1;
        val = __Pyx_PyInt_AsLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
#include "longintrepr.h"
#endif
#endif
static CYTHON_INLINE PY_LONG_LONG __Pyx_PyInt_AsLongLong(PyObject* x) {
    const PY_LONG_LONG neg_one = (PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to PY_LONG_LONG");
            return (PY_LONG_LONG)-1;
        }
        return (PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(PY_LONG_LONG)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return (PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to PY_LONG_LONG");
                return (PY_LONG_LONG)-1;
            }
            return (PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(PY_LONG_LONG)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return +(PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                    case -1: return -(PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            return (PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
#include "longintrepr.h"
#endif
#endif
static CYTHON_INLINE signed long __Pyx_PyInt_AsSignedLong(PyObject* x) {
    const signed long neg_one = (signed long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to signed long");
            return (signed long)-1;
        }
        return (signed long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(signed long)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return (signed long) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to signed long");
                return (signed long)-1;
            }
            return (signed long)PyLong_AsUnsignedLong(x);
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(signed long)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return +(signed long) ((PyLongObject*)x)->ob_digit[0];
                    case -1: return -(signed long) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            return (signed long)PyLong_AsLong(x);
        }
    } else {
        signed long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (signed long)-1;
        val = __Pyx_PyInt_AsSignedLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
#include "longintrepr.h"
#endif
#endif
static CYTHON_INLINE signed PY_LONG_LONG __Pyx_PyInt_AsSignedLongLong(PyObject* x) {
    const signed PY_LONG_LONG neg_one = (signed PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to signed PY_LONG_LONG");
            return (signed PY_LONG_LONG)-1;
        }
        return (signed PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(signed PY_LONG_LONG)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return (signed PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to signed PY_LONG_LONG");
                return (signed PY_LONG_LONG)-1;
            }
            return (signed PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
#if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(signed PY_LONG_LONG)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return +(signed PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                    case -1: return -(signed PY_LONG_LONG) ((PyLongObject*)x)->ob_digit[0];
                }
            }
#endif
#endif
            return (signed PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        signed PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (signed PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsSignedLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        #if PY_VERSION_HEX < 0x02050000
        return PyErr_Warn(NULL, message);
        #else
        return PyErr_WarnEx(NULL, message, 1);
        #endif
    }
    return 0;
}

static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = (start + end) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, new_max*sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,            /*int argcount,*/
        0,            /*int kwonlyargcount,*/
        0,            /*int nlocals,*/
        0,            /*int stacksize,*/
        0,            /*int flags,*/
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,      /*int firstlineno,*/
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_globals = 0;
    PyFrameObject *py_frame = 0;
    py_code = __pyx_find_code_object(c_line ? c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? c_line : py_line, py_code);
    }
    py_globals = PyModule_GetDict(__pyx_m);
    if (!py_globals) goto bad;
    py_frame = PyFrame_New(
        PyThreadState_GET(), /*PyThreadState *tstate,*/
        py_code,             /*PyCodeObject *code,*/
        py_globals,          /*PyObject *globals,*/
        0                    /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    py_frame->f_lineno = py_line;
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else  /* Python 3+ has unicode identifiers */
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, strlen(c_str));
}
static CYTHON_INLINE char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
static CYTHON_INLINE char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
#if PY_VERSION_HEX < 0x03030000
        char* defenc_c;
        PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
        if (!defenc) return NULL;
        defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        {
            char* end = defenc_c + PyBytes_GET_SIZE(defenc);
            char* c;
            for (c = defenc_c; c < end; c++) {
                if ((unsigned char) (*c) >= 128) {
                    PyUnicode_AsASCIIString(o);
                    return NULL;
                }
            }
        }
#endif /*__PYX_DEFAULT_STRING_ENCODING_IS_ASCII*/
        *length = PyBytes_GET_SIZE(defenc);
        return defenc_c;
#else /* PY_VERSION_HEX < 0x03030000 */
        if (PyUnicode_READY(o) == -1) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        if (PyUnicode_IS_ASCII(o)) {
            *length = PyUnicode_GET_DATA_SIZE(o);
            return PyUnicode_AsUTF8(o);
        } else {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
#else /* __PYX_DEFAULT_STRING_ENCODING_IS_ASCII */
        return PyUnicode_AsUTF8AndSize(o, length);
#endif /* __PYX_DEFAULT_STRING_ENCODING_IS_ASCII */
#endif /* PY_VERSION_HEX < 0x03030000 */
    } else
#endif /* __PYX_DEFAULT_STRING_ENCODING_IS_ASCII  || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT */
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (r < 0) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x) {
  PyNumberMethods *m;
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (PyInt_Check(x) || PyLong_Check(x))
#else
  if (PyLong_Check(x))
#endif
    return Py_INCREF(x), x;
  m = Py_TYPE(x)->tp_as_number;
#if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = PyNumber_Long(x);
  }
#else
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Long(x);
  }
#endif
  if (res) {
#if PY_MAJOR_VERSION < 3
    if (!PyInt_Check(res) && !PyLong_Check(res)) {
#else
    if (!PyLong_Check(res)) {
#endif
      PyErr_Format(PyExc_TypeError,
                   "__%s__ returned non-%s (type %.200s)",
                   name, name, Py_TYPE(res)->tp_name);
      Py_DECREF(res);
      return NULL;
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject* x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
#if PY_VERSION_HEX < 0x02050000
   if (ival <= LONG_MAX)
       return PyInt_FromLong((long)ival);
   else {
       unsigned char *bytes = (unsigned char *) &ival;
       int one = 1; int little = (int)*(unsigned char*)&one;
       return _PyLong_FromByteArray(bytes, sizeof(size_t), little, 0);
   }
#else
   return PyInt_FromSize_t(ival);
#endif
}
static CYTHON_INLINE size_t __Pyx_PyInt_AsSize_t(PyObject* x) {
   unsigned PY_LONG_LONG val = __Pyx_PyInt_AsUnsignedLongLong(x);
   if (unlikely(val != (unsigned PY_LONG_LONG)(size_t)val)) {
       if ((val != (unsigned PY_LONG_LONG)-1) || !PyErr_Occurred())
           PyErr_SetString(PyExc_OverflowError,
                           "value too large to convert to size_t");
       return (size_t)-1;
   }
   return (size_t)val;
}


#endif /* Py_PYTHON_H */
